import * as msRest from "@azure/ms-rest-js";
import * as Models from "./models";
import * as Mappers from "./models/mappers";
import { GiteaAPIContext } from "./giteaAPIContext";
declare class GiteaAPI extends GiteaAPIContext {
    /**
     * Initializes a new instance of the GiteaAPI class.
     * @param [options] The parameter options
     */
    constructor(options?: Models.GiteaAPIOptions);
    /**
     * @summary List all organizations
     * @param [options] The optional parameters
     * @returns Promise<Models.AdminGetAllOrgsResponse>
     */
    adminGetAllOrgs(options?: Models.GiteaAPIAdminGetAllOrgsOptionalParams): Promise<Models.AdminGetAllOrgsResponse>;
    /**
     * @param callback The callback
     */
    adminGetAllOrgs(callback: msRest.ServiceCallback<Models.Organization[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    adminGetAllOrgs(options: Models.GiteaAPIAdminGetAllOrgsOptionalParams, callback: msRest.ServiceCallback<Models.Organization[]>): void;
    /**
     * @summary List all users
     * @param [options] The optional parameters
     * @returns Promise<Models.AdminGetAllUsersResponse>
     */
    adminGetAllUsers(options?: Models.GiteaAPIAdminGetAllUsersOptionalParams): Promise<Models.AdminGetAllUsersResponse>;
    /**
     * @param callback The callback
     */
    adminGetAllUsers(callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    adminGetAllUsers(options: Models.GiteaAPIAdminGetAllUsersOptionalParams, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @summary Create a user
     * @param [options] The optional parameters
     * @returns Promise<Models.AdminCreateUserResponse>
     */
    adminCreateUser(options?: Models.GiteaAPIAdminCreateUserOptionalParams): Promise<Models.AdminCreateUserResponse>;
    /**
     * @param callback The callback
     */
    adminCreateUser(callback: msRest.ServiceCallback<Models.User>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    adminCreateUser(options: Models.GiteaAPIAdminCreateUserOptionalParams, callback: msRest.ServiceCallback<Models.User>): void;
    /**
     * @summary Delete a user
     * @param username username of user to delete
     * @param [options] The optional parameters
     * @returns Promise<Models.AdminDeleteUserResponse>
     */
    adminDeleteUser(username: string, options?: msRest.RequestOptionsBase): Promise<Models.AdminDeleteUserResponse>;
    /**
     * @param username username of user to delete
     * @param callback The callback
     */
    adminDeleteUser(username: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param username username of user to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    adminDeleteUser(username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Edit an existing user
     * @param username username of user to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.AdminEditUserResponse>
     */
    adminEditUser(username: string, options?: Models.GiteaAPIAdminEditUserOptionalParams): Promise<Models.AdminEditUserResponse>;
    /**
     * @param username username of user to edit
     * @param callback The callback
     */
    adminEditUser(username: string, callback: msRest.ServiceCallback<Models.User>): void;
    /**
     * @param username username of user to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    adminEditUser(username: string, options: Models.GiteaAPIAdminEditUserOptionalParams, callback: msRest.ServiceCallback<Models.User>): void;
    /**
     * @summary Add a public key on behalf of a user
     * @param username username of the user
     * @param [options] The optional parameters
     * @returns Promise<Models.AdminCreatePublicKeyResponse>
     */
    adminCreatePublicKey(username: string, options?: Models.GiteaAPIAdminCreatePublicKeyOptionalParams): Promise<Models.AdminCreatePublicKeyResponse>;
    /**
     * @param username username of the user
     * @param callback The callback
     */
    adminCreatePublicKey(username: string, callback: msRest.ServiceCallback<Models.PublicKey>): void;
    /**
     * @param username username of the user
     * @param options The optional parameters
     * @param callback The callback
     */
    adminCreatePublicKey(username: string, options: Models.GiteaAPIAdminCreatePublicKeyOptionalParams, callback: msRest.ServiceCallback<Models.PublicKey>): void;
    /**
     * @summary Delete a user's public key
     * @param username username of user
     * @param id id of the key to delete
     * @param [options] The optional parameters
     * @returns Promise<Models.AdminDeleteUserPublicKeyResponse>
     */
    adminDeleteUserPublicKey(username: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.AdminDeleteUserPublicKeyResponse>;
    /**
     * @param username username of user
     * @param id id of the key to delete
     * @param callback The callback
     */
    adminDeleteUserPublicKey(username: string, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param username username of user
     * @param id id of the key to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    adminDeleteUserPublicKey(username: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Create an organization
     * @param username username of the user that will own the created organization
     * @param organization
     * @param [options] The optional parameters
     * @returns Promise<Models.AdminCreateOrgResponse>
     */
    adminCreateOrg(username: string, organization: Models.CreateOrgOption, options?: msRest.RequestOptionsBase): Promise<Models.AdminCreateOrgResponse>;
    /**
     * @param username username of the user that will own the created organization
     * @param organization
     * @param callback The callback
     */
    adminCreateOrg(username: string, organization: Models.CreateOrgOption, callback: msRest.ServiceCallback<Models.Organization>): void;
    /**
     * @param username username of the user that will own the created organization
     * @param organization
     * @param options The optional parameters
     * @param callback The callback
     */
    adminCreateOrg(username: string, organization: Models.CreateOrgOption, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Organization>): void;
    /**
     * @summary Create a repository on behalf of a user
     * @param username username of the user. This user will own the created repository
     * @param repository
     * @param [options] The optional parameters
     * @returns Promise<Models.AdminCreateRepoResponse>
     */
    adminCreateRepo(username: string, repository: Models.CreateRepoOption, options?: msRest.RequestOptionsBase): Promise<Models.AdminCreateRepoResponse>;
    /**
     * @param username username of the user. This user will own the created repository
     * @param repository
     * @param callback The callback
     */
    adminCreateRepo(username: string, repository: Models.CreateRepoOption, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @param username username of the user. This user will own the created repository
     * @param repository
     * @param options The optional parameters
     * @param callback The callback
     */
    adminCreateRepo(username: string, repository: Models.CreateRepoOption, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @summary Render a markdown document as HTML
     * @param [options] The optional parameters
     * @returns Promise<Models.RenderMarkdownResponse>
     */
    renderMarkdown(options?: Models.GiteaAPIRenderMarkdownOptionalParams): Promise<Models.RenderMarkdownResponse>;
    /**
     * @param callback The callback
     */
    renderMarkdown(callback: msRest.ServiceCallback<string>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    renderMarkdown(options: Models.GiteaAPIRenderMarkdownOptionalParams, callback: msRest.ServiceCallback<string>): void;
    /**
     * @summary Render raw markdown as HTML
     * @param body Request body to render
     * @param [options] The optional parameters
     * @returns Promise<Models.RenderMarkdownRawResponse>
     */
    renderMarkdownRaw(body: string, options?: msRest.RequestOptionsBase): Promise<Models.RenderMarkdownRawResponse>;
    /**
     * @param body Request body to render
     * @param callback The callback
     */
    renderMarkdownRaw(body: string, callback: msRest.ServiceCallback<string>): void;
    /**
     * @param body Request body to render
     * @param options The optional parameters
     * @param callback The callback
     */
    renderMarkdownRaw(body: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<string>): void;
    /**
     * @summary List users's notification threads
     * @param [options] The optional parameters
     * @returns Promise<Models.NotifyGetListResponse>
     */
    notifyGetList(options?: Models.GiteaAPINotifyGetListOptionalParams): Promise<Models.NotifyGetListResponse>;
    /**
     * @param callback The callback
     */
    notifyGetList(callback: msRest.ServiceCallback<Models.NotificationThread[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    notifyGetList(options: Models.GiteaAPINotifyGetListOptionalParams, callback: msRest.ServiceCallback<Models.NotificationThread[]>): void;
    /**
     * @summary Mark notification threads as read
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    notifyReadList(options?: Models.GiteaAPINotifyReadListOptionalParams): Promise<msRest.RestResponse>;
    /**
     * @param callback The callback
     */
    notifyReadList(callback: msRest.ServiceCallback<void>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    notifyReadList(options: Models.GiteaAPINotifyReadListOptionalParams, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Check if unread notifications exist
     * @param [options] The optional parameters
     * @returns Promise<Models.NotifyNewAvailableResponse>
     */
    notifyNewAvailable(options?: msRest.RequestOptionsBase): Promise<Models.NotifyNewAvailableResponse>;
    /**
     * @param callback The callback
     */
    notifyNewAvailable(callback: msRest.ServiceCallback<Models.NotificationCount>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    notifyNewAvailable(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.NotificationCount>): void;
    /**
     * @summary Get notification thread by ID
     * @param id id of notification thread
     * @param [options] The optional parameters
     * @returns Promise<Models.NotifyGetThreadResponse>
     */
    notifyGetThread(id: string, options?: msRest.RequestOptionsBase): Promise<Models.NotifyGetThreadResponse>;
    /**
     * @param id id of notification thread
     * @param callback The callback
     */
    notifyGetThread(id: string, callback: msRest.ServiceCallback<Models.NotificationThread>): void;
    /**
     * @param id id of notification thread
     * @param options The optional parameters
     * @param callback The callback
     */
    notifyGetThread(id: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.NotificationThread>): void;
    /**
     * @summary Mark notification thread as read by ID
     * @param id id of notification thread
     * @param [options] The optional parameters
     * @returns Promise<Models.NotifyReadThreadResponse>
     */
    notifyReadThread(id: string, options?: msRest.RequestOptionsBase): Promise<Models.NotifyReadThreadResponse>;
    /**
     * @param id id of notification thread
     * @param callback The callback
     */
    notifyReadThread(id: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param id id of notification thread
     * @param options The optional parameters
     * @param callback The callback
     */
    notifyReadThread(id: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Create a repository in an organization
     * @param org name of organization
     * @param [options] The optional parameters
     * @deprecated This operation is deprecated. Please do not use it any longer.
     * @returns Promise<Models.CreateOrgRepoDeprecatedResponse>
     */
    createOrgRepoDeprecated(org: string, options?: Models.GiteaAPICreateOrgRepoDeprecatedOptionalParams): Promise<Models.CreateOrgRepoDeprecatedResponse>;
    /**
     * @param org name of organization
     * @param callback The callback
     * @deprecated This operation is deprecated. Please do not use it any longer.
     */
    createOrgRepoDeprecated(org: string, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @param org name of organization
     * @param options The optional parameters
     * @param callback The callback
     * @deprecated This operation is deprecated. Please do not use it any longer.
     */
    createOrgRepoDeprecated(org: string, options: Models.GiteaAPICreateOrgRepoDeprecatedOptionalParams, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @summary Get list of organizations
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgGetAllResponse>
     */
    orgGetAll(options?: Models.GiteaAPIOrgGetAllOptionalParams): Promise<Models.OrgGetAllResponse>;
    /**
     * @param callback The callback
     */
    orgGetAll(callback: msRest.ServiceCallback<Models.Organization[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    orgGetAll(options: Models.GiteaAPIOrgGetAllOptionalParams, callback: msRest.ServiceCallback<Models.Organization[]>): void;
    /**
     * @summary Create an organization
     * @param organization
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgCreateResponse>
     */
    orgCreate(organization: Models.CreateOrgOption, options?: msRest.RequestOptionsBase): Promise<Models.OrgCreateResponse>;
    /**
     * @param organization
     * @param callback The callback
     */
    orgCreate(organization: Models.CreateOrgOption, callback: msRest.ServiceCallback<Models.Organization>): void;
    /**
     * @param organization
     * @param options The optional parameters
     * @param callback The callback
     */
    orgCreate(organization: Models.CreateOrgOption, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Organization>): void;
    /**
     * @summary Get an organization
     * @param org name of the organization to get
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgGetResponse>
     */
    orgGet(org: string, options?: msRest.RequestOptionsBase): Promise<Models.OrgGetResponse>;
    /**
     * @param org name of the organization to get
     * @param callback The callback
     */
    orgGet(org: string, callback: msRest.ServiceCallback<Models.Organization>): void;
    /**
     * @param org name of the organization to get
     * @param options The optional parameters
     * @param callback The callback
     */
    orgGet(org: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Organization>): void;
    /**
     * @summary Delete an organization
     * @param org organization that is to be deleted
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    orgDelete(org: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param org organization that is to be deleted
     * @param callback The callback
     */
    orgDelete(org: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param org organization that is to be deleted
     * @param options The optional parameters
     * @param callback The callback
     */
    orgDelete(org: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Edit an organization
     * @param org name of the organization to edit
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgEditResponse>
     */
    orgEdit(org: string, body: Models.EditOrgOption, options?: msRest.RequestOptionsBase): Promise<Models.OrgEditResponse>;
    /**
     * @param org name of the organization to edit
     * @param body
     * @param callback The callback
     */
    orgEdit(org: string, body: Models.EditOrgOption, callback: msRest.ServiceCallback<Models.Organization>): void;
    /**
     * @param org name of the organization to edit
     * @param body
     * @param options The optional parameters
     * @param callback The callback
     */
    orgEdit(org: string, body: Models.EditOrgOption, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Organization>): void;
    /**
     * @summary List an organization's webhooks
     * @param org name of the organization
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgListHooksResponse>
     */
    orgListHooks(org: string, options?: Models.GiteaAPIOrgListHooksOptionalParams): Promise<Models.OrgListHooksResponse>;
    /**
     * @param org name of the organization
     * @param callback The callback
     */
    orgListHooks(org: string, callback: msRest.ServiceCallback<Models.Hook[]>): void;
    /**
     * @param org name of the organization
     * @param options The optional parameters
     * @param callback The callback
     */
    orgListHooks(org: string, options: Models.GiteaAPIOrgListHooksOptionalParams, callback: msRest.ServiceCallback<Models.Hook[]>): void;
    /**
     * @summary Create a hook
     * @param org name of the organization
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgCreateHookResponse>
     */
    orgCreateHook(org: string, body: Models.CreateHookOption, options?: msRest.RequestOptionsBase): Promise<Models.OrgCreateHookResponse>;
    /**
     * @param org name of the organization
     * @param body
     * @param callback The callback
     */
    orgCreateHook(org: string, body: Models.CreateHookOption, callback: msRest.ServiceCallback<Models.Hook>): void;
    /**
     * @param org name of the organization
     * @param body
     * @param options The optional parameters
     * @param callback The callback
     */
    orgCreateHook(org: string, body: Models.CreateHookOption, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Hook>): void;
    /**
     * @summary Get a hook
     * @param org name of the organization
     * @param id id of the hook to get
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgGetHookResponse>
     */
    orgGetHook(org: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.OrgGetHookResponse>;
    /**
     * @param org name of the organization
     * @param id id of the hook to get
     * @param callback The callback
     */
    orgGetHook(org: string, id: number, callback: msRest.ServiceCallback<Models.Hook>): void;
    /**
     * @param org name of the organization
     * @param id id of the hook to get
     * @param options The optional parameters
     * @param callback The callback
     */
    orgGetHook(org: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Hook>): void;
    /**
     * @summary Delete a hook
     * @param org name of the organization
     * @param id id of the hook to delete
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    orgDeleteHook(org: string, id: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param org name of the organization
     * @param id id of the hook to delete
     * @param callback The callback
     */
    orgDeleteHook(org: string, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param org name of the organization
     * @param id id of the hook to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    orgDeleteHook(org: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Update a hook
     * @param org name of the organization
     * @param id id of the hook to update
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgEditHookResponse>
     */
    orgEditHook(org: string, id: number, options?: Models.GiteaAPIOrgEditHookOptionalParams): Promise<Models.OrgEditHookResponse>;
    /**
     * @param org name of the organization
     * @param id id of the hook to update
     * @param callback The callback
     */
    orgEditHook(org: string, id: number, callback: msRest.ServiceCallback<Models.Hook>): void;
    /**
     * @param org name of the organization
     * @param id id of the hook to update
     * @param options The optional parameters
     * @param callback The callback
     */
    orgEditHook(org: string, id: number, options: Models.GiteaAPIOrgEditHookOptionalParams, callback: msRest.ServiceCallback<Models.Hook>): void;
    /**
     * @summary List an organization's labels
     * @param org name of the organization
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgListLabelsResponse>
     */
    orgListLabels(org: string, options?: Models.GiteaAPIOrgListLabelsOptionalParams): Promise<Models.OrgListLabelsResponse>;
    /**
     * @param org name of the organization
     * @param callback The callback
     */
    orgListLabels(org: string, callback: msRest.ServiceCallback<Models.Label[]>): void;
    /**
     * @param org name of the organization
     * @param options The optional parameters
     * @param callback The callback
     */
    orgListLabels(org: string, options: Models.GiteaAPIOrgListLabelsOptionalParams, callback: msRest.ServiceCallback<Models.Label[]>): void;
    /**
     * @summary Create a label for an organization
     * @param org name of the organization
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgCreateLabelResponse>
     */
    orgCreateLabel(org: string, options?: Models.GiteaAPIOrgCreateLabelOptionalParams): Promise<Models.OrgCreateLabelResponse>;
    /**
     * @param org name of the organization
     * @param callback The callback
     */
    orgCreateLabel(org: string, callback: msRest.ServiceCallback<Models.Label>): void;
    /**
     * @param org name of the organization
     * @param options The optional parameters
     * @param callback The callback
     */
    orgCreateLabel(org: string, options: Models.GiteaAPIOrgCreateLabelOptionalParams, callback: msRest.ServiceCallback<Models.Label>): void;
    /**
     * @summary Get a single label
     * @param org name of the organization
     * @param id id of the label to get
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgGetLabelResponse>
     */
    orgGetLabel(org: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.OrgGetLabelResponse>;
    /**
     * @param org name of the organization
     * @param id id of the label to get
     * @param callback The callback
     */
    orgGetLabel(org: string, id: number, callback: msRest.ServiceCallback<Models.Label>): void;
    /**
     * @param org name of the organization
     * @param id id of the label to get
     * @param options The optional parameters
     * @param callback The callback
     */
    orgGetLabel(org: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Label>): void;
    /**
     * @summary Delete a label
     * @param org name of the organization
     * @param id id of the label to delete
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    orgDeleteLabel(org: string, id: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param org name of the organization
     * @param id id of the label to delete
     * @param callback The callback
     */
    orgDeleteLabel(org: string, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param org name of the organization
     * @param id id of the label to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    orgDeleteLabel(org: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Update a label
     * @param org name of the organization
     * @param id id of the label to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgEditLabelResponse>
     */
    orgEditLabel(org: string, id: number, options?: Models.GiteaAPIOrgEditLabelOptionalParams): Promise<Models.OrgEditLabelResponse>;
    /**
     * @param org name of the organization
     * @param id id of the label to edit
     * @param callback The callback
     */
    orgEditLabel(org: string, id: number, callback: msRest.ServiceCallback<Models.Label>): void;
    /**
     * @param org name of the organization
     * @param id id of the label to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    orgEditLabel(org: string, id: number, options: Models.GiteaAPIOrgEditLabelOptionalParams, callback: msRest.ServiceCallback<Models.Label>): void;
    /**
     * @summary List an organization's members
     * @param org name of the organization
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgListMembersResponse>
     */
    orgListMembers(org: string, options?: Models.GiteaAPIOrgListMembersOptionalParams): Promise<Models.OrgListMembersResponse>;
    /**
     * @param org name of the organization
     * @param callback The callback
     */
    orgListMembers(org: string, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @param org name of the organization
     * @param options The optional parameters
     * @param callback The callback
     */
    orgListMembers(org: string, options: Models.GiteaAPIOrgListMembersOptionalParams, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @summary Check if a user is a member of an organization
     * @param org name of the organization
     * @param username username of the user
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    orgIsMember(org: string, username: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param org name of the organization
     * @param username username of the user
     * @param callback The callback
     */
    orgIsMember(org: string, username: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param org name of the organization
     * @param username username of the user
     * @param options The optional parameters
     * @param callback The callback
     */
    orgIsMember(org: string, username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Remove a member from an organization
     * @param org name of the organization
     * @param username username of the user
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    orgDeleteMember(org: string, username: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param org name of the organization
     * @param username username of the user
     * @param callback The callback
     */
    orgDeleteMember(org: string, username: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param org name of the organization
     * @param username username of the user
     * @param options The optional parameters
     * @param callback The callback
     */
    orgDeleteMember(org: string, username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List an organization's public members
     * @param org name of the organization
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgListPublicMembersResponse>
     */
    orgListPublicMembers(org: string, options?: Models.GiteaAPIOrgListPublicMembersOptionalParams): Promise<Models.OrgListPublicMembersResponse>;
    /**
     * @param org name of the organization
     * @param callback The callback
     */
    orgListPublicMembers(org: string, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @param org name of the organization
     * @param options The optional parameters
     * @param callback The callback
     */
    orgListPublicMembers(org: string, options: Models.GiteaAPIOrgListPublicMembersOptionalParams, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @summary Check if a user is a public member of an organization
     * @param org name of the organization
     * @param username username of the user
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    orgIsPublicMember(org: string, username: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param org name of the organization
     * @param username username of the user
     * @param callback The callback
     */
    orgIsPublicMember(org: string, username: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param org name of the organization
     * @param username username of the user
     * @param options The optional parameters
     * @param callback The callback
     */
    orgIsPublicMember(org: string, username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Publicize a user's membership
     * @param org name of the organization
     * @param username username of the user
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgPublicizeMemberResponse>
     */
    orgPublicizeMember(org: string, username: string, options?: msRest.RequestOptionsBase): Promise<Models.OrgPublicizeMemberResponse>;
    /**
     * @param org name of the organization
     * @param username username of the user
     * @param callback The callback
     */
    orgPublicizeMember(org: string, username: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param org name of the organization
     * @param username username of the user
     * @param options The optional parameters
     * @param callback The callback
     */
    orgPublicizeMember(org: string, username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Conceal a user's membership
     * @param org name of the organization
     * @param username username of the user
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgConcealMemberResponse>
     */
    orgConcealMember(org: string, username: string, options?: msRest.RequestOptionsBase): Promise<Models.OrgConcealMemberResponse>;
    /**
     * @param org name of the organization
     * @param username username of the user
     * @param callback The callback
     */
    orgConcealMember(org: string, username: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param org name of the organization
     * @param username username of the user
     * @param options The optional parameters
     * @param callback The callback
     */
    orgConcealMember(org: string, username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List an organization's repos
     * @param org name of the organization
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgListReposResponse>
     */
    orgListRepos(org: string, options?: Models.GiteaAPIOrgListReposOptionalParams): Promise<Models.OrgListReposResponse>;
    /**
     * @param org name of the organization
     * @param callback The callback
     */
    orgListRepos(org: string, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @param org name of the organization
     * @param options The optional parameters
     * @param callback The callback
     */
    orgListRepos(org: string, options: Models.GiteaAPIOrgListReposOptionalParams, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @summary Create a repository in an organization
     * @param org name of organization
     * @param [options] The optional parameters
     * @returns Promise<Models.CreateOrgRepoResponse>
     */
    createOrgRepo(org: string, options?: Models.GiteaAPICreateOrgRepoOptionalParams): Promise<Models.CreateOrgRepoResponse>;
    /**
     * @param org name of organization
     * @param callback The callback
     */
    createOrgRepo(org: string, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @param org name of organization
     * @param options The optional parameters
     * @param callback The callback
     */
    createOrgRepo(org: string, options: Models.GiteaAPICreateOrgRepoOptionalParams, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @summary List an organization's teams
     * @param org name of the organization
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgListTeamsResponse>
     */
    orgListTeams(org: string, options?: Models.GiteaAPIOrgListTeamsOptionalParams): Promise<Models.OrgListTeamsResponse>;
    /**
     * @param org name of the organization
     * @param callback The callback
     */
    orgListTeams(org: string, callback: msRest.ServiceCallback<Models.Team[]>): void;
    /**
     * @param org name of the organization
     * @param options The optional parameters
     * @param callback The callback
     */
    orgListTeams(org: string, options: Models.GiteaAPIOrgListTeamsOptionalParams, callback: msRest.ServiceCallback<Models.Team[]>): void;
    /**
     * @summary Create a team
     * @param org name of the organization
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgCreateTeamResponse>
     */
    orgCreateTeam(org: string, options?: Models.GiteaAPIOrgCreateTeamOptionalParams): Promise<Models.OrgCreateTeamResponse>;
    /**
     * @param org name of the organization
     * @param callback The callback
     */
    orgCreateTeam(org: string, callback: msRest.ServiceCallback<Models.Team>): void;
    /**
     * @param org name of the organization
     * @param options The optional parameters
     * @param callback The callback
     */
    orgCreateTeam(org: string, options: Models.GiteaAPIOrgCreateTeamOptionalParams, callback: msRest.ServiceCallback<Models.Team>): void;
    /**
     * @summary Search for teams within an organization
     * @param org name of the organization
     * @param [options] The optional parameters
     * @returns Promise<Models.TeamSearchResponse>
     */
    teamSearch(org: string, options?: Models.GiteaAPITeamSearchOptionalParams): Promise<Models.TeamSearchResponse>;
    /**
     * @param org name of the organization
     * @param callback The callback
     */
    teamSearch(org: string, callback: msRest.ServiceCallback<Models.TeamSearchOKResponse>): void;
    /**
     * @param org name of the organization
     * @param options The optional parameters
     * @param callback The callback
     */
    teamSearch(org: string, options: Models.GiteaAPITeamSearchOptionalParams, callback: msRest.ServiceCallback<Models.TeamSearchOKResponse>): void;
    /**
     * @summary Search for issues across the repositories that the user has access to
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueSearchIssuesResponse>
     */
    issueSearchIssues(options?: Models.GiteaAPIIssueSearchIssuesOptionalParams): Promise<Models.IssueSearchIssuesResponse>;
    /**
     * @param callback The callback
     */
    issueSearchIssues(callback: msRest.ServiceCallback<Models.Issue[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    issueSearchIssues(options: Models.GiteaAPIIssueSearchIssuesOptionalParams, callback: msRest.ServiceCallback<Models.Issue[]>): void;
    /**
     * @summary Migrate a remote git repository
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoMigrateResponse>
     */
    repoMigrate(options?: Models.GiteaAPIRepoMigrateOptionalParams): Promise<Models.RepoMigrateResponse>;
    /**
     * @param callback The callback
     */
    repoMigrate(callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    repoMigrate(options: Models.GiteaAPIRepoMigrateOptionalParams, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @summary Search for repositories
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoSearchResponse>
     */
    repoSearch(options?: Models.GiteaAPIRepoSearchOptionalParams): Promise<Models.RepoSearchResponse>;
    /**
     * @param callback The callback
     */
    repoSearch(callback: msRest.ServiceCallback<Models.SearchResults>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    repoSearch(options: Models.GiteaAPIRepoSearchOptionalParams, callback: msRest.ServiceCallback<Models.SearchResults>): void;
    /**
     * @summary Get a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetResponse>
     */
    repoGet(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoGet(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGet(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @summary Delete a repository
     * @param owner owner of the repo to delete
     * @param repo name of the repo to delete
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoDeleteResponse>
     */
    repoDelete(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoDeleteResponse>;
    /**
     * @param owner owner of the repo to delete
     * @param repo name of the repo to delete
     * @param callback The callback
     */
    repoDelete(owner: string, repo: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo to delete
     * @param repo name of the repo to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    repoDelete(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Edit a repository's properties. Only fields that are set will be changed.
     * @param owner owner of the repo to edit
     * @param repo name of the repo to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoEditResponse>
     */
    repoEdit(owner: string, repo: string, options?: Models.GiteaAPIRepoEditOptionalParams): Promise<Models.RepoEditResponse>;
    /**
     * @param owner owner of the repo to edit
     * @param repo name of the repo to edit
     * @param callback The callback
     */
    repoEdit(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @param owner owner of the repo to edit
     * @param repo name of the repo to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    repoEdit(owner: string, repo: string, options: Models.GiteaAPIRepoEditOptionalParams, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @summary Get an archive of a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param archive archive to download, consisting of a git reference and archive
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    repoGetArchive(owner: string, repo: string, archive: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param archive archive to download, consisting of a git reference and archive
     * @param callback The callback
     */
    repoGetArchive(owner: string, repo: string, archive: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param archive archive to download, consisting of a git reference and archive
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetArchive(owner: string, repo: string, archive: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List branch protections for a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListBranchProtectionResponse>
     */
    repoListBranchProtection(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoListBranchProtectionResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListBranchProtection(owner: string, repo: string, callback: msRest.ServiceCallback<Models.BranchProtection[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListBranchProtection(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.BranchProtection[]>): void;
    /**
     * @summary Create a branch protections for a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoCreateBranchProtectionResponse>
     */
    repoCreateBranchProtection(owner: string, repo: string, options?: Models.GiteaAPIRepoCreateBranchProtectionOptionalParams): Promise<Models.RepoCreateBranchProtectionResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoCreateBranchProtection(owner: string, repo: string, callback: msRest.ServiceCallback<Models.BranchProtection>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoCreateBranchProtection(owner: string, repo: string, options: Models.GiteaAPIRepoCreateBranchProtectionOptionalParams, callback: msRest.ServiceCallback<Models.BranchProtection>): void;
    /**
     * @summary Get a specific branch protection for the repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param name name of protected branch
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetBranchProtectionResponse>
     */
    repoGetBranchProtection(owner: string, repo: string, name: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetBranchProtectionResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param name name of protected branch
     * @param callback The callback
     */
    repoGetBranchProtection(owner: string, repo: string, name: string, callback: msRest.ServiceCallback<Models.BranchProtection>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param name name of protected branch
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetBranchProtection(owner: string, repo: string, name: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.BranchProtection>): void;
    /**
     * @summary Delete a specific branch protection for the repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param name name of protected branch
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    repoDeleteBranchProtection(owner: string, repo: string, name: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param name name of protected branch
     * @param callback The callback
     */
    repoDeleteBranchProtection(owner: string, repo: string, name: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param name name of protected branch
     * @param options The optional parameters
     * @param callback The callback
     */
    repoDeleteBranchProtection(owner: string, repo: string, name: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Edit a branch protections for a repository. Only fields that are set will be changed
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param name name of protected branch
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoEditBranchProtectionResponse>
     */
    repoEditBranchProtection(owner: string, repo: string, name: string, options?: Models.GiteaAPIRepoEditBranchProtectionOptionalParams): Promise<Models.RepoEditBranchProtectionResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param name name of protected branch
     * @param callback The callback
     */
    repoEditBranchProtection(owner: string, repo: string, name: string, callback: msRest.ServiceCallback<Models.BranchProtection>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param name name of protected branch
     * @param options The optional parameters
     * @param callback The callback
     */
    repoEditBranchProtection(owner: string, repo: string, name: string, options: Models.GiteaAPIRepoEditBranchProtectionOptionalParams, callback: msRest.ServiceCallback<Models.BranchProtection>): void;
    /**
     * @summary List a repository's branches
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListBranchesResponse>
     */
    repoListBranches(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoListBranchesResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListBranches(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Branch[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListBranches(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Branch[]>): void;
    /**
     * @summary Retrieve a specific branch from a repository, including its effective branch protection
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param branch branch to get
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetBranchResponse>
     */
    repoGetBranch(owner: string, repo: string, branch: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetBranchResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param branch branch to get
     * @param callback The callback
     */
    repoGetBranch(owner: string, repo: string, branch: string, callback: msRest.ServiceCallback<Models.Branch>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param branch branch to get
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetBranch(owner: string, repo: string, branch: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Branch>): void;
    /**
     * @summary Delete a specific branch from a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param branch branch to delete
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoDeleteBranchResponse>
     */
    repoDeleteBranch(owner: string, repo: string, branch: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoDeleteBranchResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param branch branch to delete
     * @param callback The callback
     */
    repoDeleteBranch(owner: string, repo: string, branch: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param branch branch to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    repoDeleteBranch(owner: string, repo: string, branch: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List a repository's collaborators
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListCollaboratorsResponse>
     */
    repoListCollaborators(owner: string, repo: string, options?: Models.GiteaAPIRepoListCollaboratorsOptionalParams): Promise<Models.RepoListCollaboratorsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListCollaborators(owner: string, repo: string, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListCollaborators(owner: string, repo: string, options: Models.GiteaAPIRepoListCollaboratorsOptionalParams, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @summary Check if a user is a collaborator of a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param collaborator username of the collaborator
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoCheckCollaboratorResponse>
     */
    repoCheckCollaborator(owner: string, repo: string, collaborator: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoCheckCollaboratorResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param collaborator username of the collaborator
     * @param callback The callback
     */
    repoCheckCollaborator(owner: string, repo: string, collaborator: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param collaborator username of the collaborator
     * @param options The optional parameters
     * @param callback The callback
     */
    repoCheckCollaborator(owner: string, repo: string, collaborator: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Add a collaborator to a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param collaborator username of the collaborator to add
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoAddCollaboratorResponse>
     */
    repoAddCollaborator(owner: string, repo: string, collaborator: string, options?: Models.GiteaAPIRepoAddCollaboratorOptionalParams): Promise<Models.RepoAddCollaboratorResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param collaborator username of the collaborator to add
     * @param callback The callback
     */
    repoAddCollaborator(owner: string, repo: string, collaborator: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param collaborator username of the collaborator to add
     * @param options The optional parameters
     * @param callback The callback
     */
    repoAddCollaborator(owner: string, repo: string, collaborator: string, options: Models.GiteaAPIRepoAddCollaboratorOptionalParams, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Delete a collaborator from a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param collaborator username of the collaborator to delete
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoDeleteCollaboratorResponse>
     */
    repoDeleteCollaborator(owner: string, repo: string, collaborator: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoDeleteCollaboratorResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param collaborator username of the collaborator to delete
     * @param callback The callback
     */
    repoDeleteCollaborator(owner: string, repo: string, collaborator: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param collaborator username of the collaborator to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    repoDeleteCollaborator(owner: string, repo: string, collaborator: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Get a list of all commits from a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetAllCommitsResponse>
     */
    repoGetAllCommits(owner: string, repo: string, options?: Models.GiteaAPIRepoGetAllCommitsOptionalParams): Promise<Models.RepoGetAllCommitsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoGetAllCommits(owner: string, repo: string, callback: msRest.ServiceCallback<any>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetAllCommits(owner: string, repo: string, options: Models.GiteaAPIRepoGetAllCommitsOptionalParams, callback: msRest.ServiceCallback<any>): void;
    /**
     * @summary Get a commit's combined status, by branch/tag/commit reference
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param ref name of branch/tag/commit
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetCombinedStatusByRefResponse>
     */
    repoGetCombinedStatusByRef(owner: string, repo: string, ref: string, options?: Models.GiteaAPIRepoGetCombinedStatusByRefOptionalParams): Promise<Models.RepoGetCombinedStatusByRefResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param ref name of branch/tag/commit
     * @param callback The callback
     */
    repoGetCombinedStatusByRef(owner: string, repo: string, ref: string, callback: msRest.ServiceCallback<Models.Status>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param ref name of branch/tag/commit
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetCombinedStatusByRef(owner: string, repo: string, ref: string, options: Models.GiteaAPIRepoGetCombinedStatusByRefOptionalParams, callback: msRest.ServiceCallback<Models.Status>): void;
    /**
     * @summary Gets the metadata of all the entries of the root dir
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetContentsListResponse>
     */
    repoGetContentsList(owner: string, repo: string, options?: Models.GiteaAPIRepoGetContentsListOptionalParams): Promise<Models.RepoGetContentsListResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoGetContentsList(owner: string, repo: string, callback: msRest.ServiceCallback<Models.ContentsResponse[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetContentsList(owner: string, repo: string, options: Models.GiteaAPIRepoGetContentsListOptionalParams, callback: msRest.ServiceCallback<Models.ContentsResponse[]>): void;
    /**
     * @summary Gets the metadata and contents (if a file) of an entry in a repository, or a list of
     * entries if a dir
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath path of the dir, file, symlink or submodule in the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetContentsResponse>
     */
    repoGetContents(owner: string, repo: string, filepath: string, options?: Models.GiteaAPIRepoGetContentsOptionalParams): Promise<Models.RepoGetContentsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath path of the dir, file, symlink or submodule in the repo
     * @param callback The callback
     */
    repoGetContents(owner: string, repo: string, filepath: string, callback: msRest.ServiceCallback<Models.ContentsResponse>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath path of the dir, file, symlink or submodule in the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetContents(owner: string, repo: string, filepath: string, options: Models.GiteaAPIRepoGetContentsOptionalParams, callback: msRest.ServiceCallback<Models.ContentsResponse>): void;
    /**
     * @summary Update a file in a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath path of the file to update
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoUpdateFileResponse>
     */
    repoUpdateFile(owner: string, repo: string, filepath: string, body: Models.UpdateFileOptions, options?: msRest.RequestOptionsBase): Promise<Models.RepoUpdateFileResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath path of the file to update
     * @param body
     * @param callback The callback
     */
    repoUpdateFile(owner: string, repo: string, filepath: string, body: Models.UpdateFileOptions, callback: msRest.ServiceCallback<Models.FileResponse>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath path of the file to update
     * @param body
     * @param options The optional parameters
     * @param callback The callback
     */
    repoUpdateFile(owner: string, repo: string, filepath: string, body: Models.UpdateFileOptions, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.FileResponse>): void;
    /**
     * @summary Create a file in a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath path of the file to create
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoCreateFileResponse>
     */
    repoCreateFile(owner: string, repo: string, filepath: string, body: Models.CreateFileOptions, options?: msRest.RequestOptionsBase): Promise<Models.RepoCreateFileResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath path of the file to create
     * @param body
     * @param callback The callback
     */
    repoCreateFile(owner: string, repo: string, filepath: string, body: Models.CreateFileOptions, callback: msRest.ServiceCallback<Models.FileResponse>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath path of the file to create
     * @param body
     * @param options The optional parameters
     * @param callback The callback
     */
    repoCreateFile(owner: string, repo: string, filepath: string, body: Models.CreateFileOptions, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.FileResponse>): void;
    /**
     * @summary Delete a file in a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath path of the file to delete
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoDeleteFileResponse>
     */
    repoDeleteFile(owner: string, repo: string, filepath: string, body: Models.DeleteFileOptions, options?: msRest.RequestOptionsBase): Promise<Models.RepoDeleteFileResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath path of the file to delete
     * @param body
     * @param callback The callback
     */
    repoDeleteFile(owner: string, repo: string, filepath: string, body: Models.DeleteFileOptions, callback: msRest.ServiceCallback<Models.FileDeleteResponse>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath path of the file to delete
     * @param body
     * @param options The optional parameters
     * @param callback The callback
     */
    repoDeleteFile(owner: string, repo: string, filepath: string, body: Models.DeleteFileOptions, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.FileDeleteResponse>): void;
    /**
     * @summary Get the EditorConfig definitions of a file in a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath filepath of file to get
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    repoGetEditorConfig(owner: string, repo: string, filepath: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath filepath of file to get
     * @param callback The callback
     */
    repoGetEditorConfig(owner: string, repo: string, filepath: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath filepath of file to get
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetEditorConfig(owner: string, repo: string, filepath: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List a repository's forks
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.ListForksResponse>
     */
    listForks(owner: string, repo: string, options?: Models.GiteaAPIListForksOptionalParams): Promise<Models.ListForksResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    listForks(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    listForks(owner: string, repo: string, options: Models.GiteaAPIListForksOptionalParams, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @summary Fork a repository
     * @param owner owner of the repo to fork
     * @param repo name of the repo to fork
     * @param [options] The optional parameters
     * @returns Promise<Models.CreateForkResponse>
     */
    createFork(owner: string, repo: string, options?: Models.GiteaAPICreateForkOptionalParams): Promise<Models.CreateForkResponse>;
    /**
     * @param owner owner of the repo to fork
     * @param repo name of the repo to fork
     * @param callback The callback
     */
    createFork(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @param owner owner of the repo to fork
     * @param repo name of the repo to fork
     * @param options The optional parameters
     * @param callback The callback
     */
    createFork(owner: string, repo: string, options: Models.GiteaAPICreateForkOptionalParams, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @summary Gets the blob of a repository.
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the commit
     * @param [options] The optional parameters
     * @returns Promise<Models.GetBlobResponse>
     */
    getBlob(owner: string, repo: string, sha: string, options?: msRest.RequestOptionsBase): Promise<Models.GetBlobResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the commit
     * @param callback The callback
     */
    getBlob(owner: string, repo: string, sha: string, callback: msRest.ServiceCallback<Models.GitBlobResponse>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the commit
     * @param options The optional parameters
     * @param callback The callback
     */
    getBlob(owner: string, repo: string, sha: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.GitBlobResponse>): void;
    /**
     * @summary Get a single commit from a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha a git ref or commit sha
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetSingleCommitResponse>
     */
    repoGetSingleCommit(owner: string, repo: string, sha: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetSingleCommitResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha a git ref or commit sha
     * @param callback The callback
     */
    repoGetSingleCommit(owner: string, repo: string, sha: string, callback: msRest.ServiceCallback<Models.Commit>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha a git ref or commit sha
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetSingleCommit(owner: string, repo: string, sha: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Commit>): void;
    /**
     * @summary Get specified ref or filtered repository's refs
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListAllGitRefsResponse>
     */
    repoListAllGitRefs(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoListAllGitRefsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListAllGitRefs(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Reference[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListAllGitRefs(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Reference[]>): void;
    /**
     * @summary Get specified ref or filtered repository's refs
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param ref part or full name of the ref
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListGitRefsResponse>
     */
    repoListGitRefs(owner: string, repo: string, ref: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoListGitRefsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param ref part or full name of the ref
     * @param callback The callback
     */
    repoListGitRefs(owner: string, repo: string, ref: string, callback: msRest.ServiceCallback<Models.Reference[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param ref part or full name of the ref
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListGitRefs(owner: string, repo: string, ref: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Reference[]>): void;
    /**
     * @summary Gets the tag object of an annotated tag (not lightweight tags)
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the tag. The Git tags API only supports annotated tag objects, not lightweight
     * tags.
     * @param [options] The optional parameters
     * @returns Promise<Models.GetTagResponse>
     */
    getTag(owner: string, repo: string, sha: string, options?: msRest.RequestOptionsBase): Promise<Models.GetTagResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the tag. The Git tags API only supports annotated tag objects, not lightweight
     * tags.
     * @param callback The callback
     */
    getTag(owner: string, repo: string, sha: string, callback: msRest.ServiceCallback<Models.AnnotatedTag>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the tag. The Git tags API only supports annotated tag objects, not lightweight
     * tags.
     * @param options The optional parameters
     * @param callback The callback
     */
    getTag(owner: string, repo: string, sha: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AnnotatedTag>): void;
    /**
     * @summary Gets the tree of a repository.
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the commit
     * @param [options] The optional parameters
     * @returns Promise<Models.GetTreeResponse>
     */
    getTree(owner: string, repo: string, sha: string, options?: Models.GiteaAPIGetTreeOptionalParams): Promise<Models.GetTreeResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the commit
     * @param callback The callback
     */
    getTree(owner: string, repo: string, sha: string, callback: msRest.ServiceCallback<Models.GitTreeResponse>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the commit
     * @param options The optional parameters
     * @param callback The callback
     */
    getTree(owner: string, repo: string, sha: string, options: Models.GiteaAPIGetTreeOptionalParams, callback: msRest.ServiceCallback<Models.GitTreeResponse>): void;
    /**
     * @summary List the hooks in a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListHooksResponse>
     */
    repoListHooks(owner: string, repo: string, options?: Models.GiteaAPIRepoListHooksOptionalParams): Promise<Models.RepoListHooksResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListHooks(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Hook[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListHooks(owner: string, repo: string, options: Models.GiteaAPIRepoListHooksOptionalParams, callback: msRest.ServiceCallback<Models.Hook[]>): void;
    /**
     * @summary Create a hook
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoCreateHookResponse>
     */
    repoCreateHook(owner: string, repo: string, options?: Models.GiteaAPIRepoCreateHookOptionalParams): Promise<Models.RepoCreateHookResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoCreateHook(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Hook>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoCreateHook(owner: string, repo: string, options: Models.GiteaAPIRepoCreateHookOptionalParams, callback: msRest.ServiceCallback<Models.Hook>): void;
    /**
     * @summary List the Git hooks in a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListGitHooksResponse>
     */
    repoListGitHooks(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoListGitHooksResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListGitHooks(owner: string, repo: string, callback: msRest.ServiceCallback<Models.GitHook[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListGitHooks(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.GitHook[]>): void;
    /**
     * @summary Get a Git hook
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to get
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetGitHookResponse>
     */
    repoGetGitHook(owner: string, repo: string, id: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetGitHookResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to get
     * @param callback The callback
     */
    repoGetGitHook(owner: string, repo: string, id: string, callback: msRest.ServiceCallback<Models.GitHook>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to get
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetGitHook(owner: string, repo: string, id: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.GitHook>): void;
    /**
     * @summary Delete a Git hook in a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to get
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    repoDeleteGitHook(owner: string, repo: string, id: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to get
     * @param callback The callback
     */
    repoDeleteGitHook(owner: string, repo: string, id: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to get
     * @param options The optional parameters
     * @param callback The callback
     */
    repoDeleteGitHook(owner: string, repo: string, id: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Edit a Git hook in a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to get
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoEditGitHookResponse>
     */
    repoEditGitHook(owner: string, repo: string, id: string, options?: Models.GiteaAPIRepoEditGitHookOptionalParams): Promise<Models.RepoEditGitHookResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to get
     * @param callback The callback
     */
    repoEditGitHook(owner: string, repo: string, id: string, callback: msRest.ServiceCallback<Models.GitHook>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to get
     * @param options The optional parameters
     * @param callback The callback
     */
    repoEditGitHook(owner: string, repo: string, id: string, options: Models.GiteaAPIRepoEditGitHookOptionalParams, callback: msRest.ServiceCallback<Models.GitHook>): void;
    /**
     * @summary Get a hook
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to get
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetHookResponse>
     */
    repoGetHook(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetHookResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to get
     * @param callback The callback
     */
    repoGetHook(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Hook>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to get
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetHook(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Hook>): void;
    /**
     * @summary Delete a hook in a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to delete
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    repoDeleteHook(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to delete
     * @param callback The callback
     */
    repoDeleteHook(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    repoDeleteHook(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Edit a hook in a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id index of the hook
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoEditHookResponse>
     */
    repoEditHook(owner: string, repo: string, id: number, options?: Models.GiteaAPIRepoEditHookOptionalParams): Promise<Models.RepoEditHookResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id index of the hook
     * @param callback The callback
     */
    repoEditHook(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Hook>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id index of the hook
     * @param options The optional parameters
     * @param callback The callback
     */
    repoEditHook(owner: string, repo: string, id: number, options: Models.GiteaAPIRepoEditHookOptionalParams, callback: msRest.ServiceCallback<Models.Hook>): void;
    /**
     * @summary Test a push webhook
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to test
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    repoTestHook(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to test
     * @param callback The callback
     */
    repoTestHook(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the hook to test
     * @param options The optional parameters
     * @param callback The callback
     */
    repoTestHook(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List a repository's issues
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueListIssuesResponse>
     */
    issueListIssues(owner: string, repo: string, options?: Models.GiteaAPIIssueListIssuesOptionalParams): Promise<Models.IssueListIssuesResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    issueListIssues(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Issue[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    issueListIssues(owner: string, repo: string, options: Models.GiteaAPIIssueListIssuesOptionalParams, callback: msRest.ServiceCallback<Models.Issue[]>): void;
    /**
     * @summary Create an issue. If using deadline only the date will be taken into account, and time
     * of day ignored.
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueCreateIssueResponse>
     */
    issueCreateIssue(owner: string, repo: string, options?: Models.GiteaAPIIssueCreateIssueOptionalParams): Promise<Models.IssueCreateIssueResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    issueCreateIssue(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Issue>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    issueCreateIssue(owner: string, repo: string, options: Models.GiteaAPIIssueCreateIssueOptionalParams, callback: msRest.ServiceCallback<Models.Issue>): void;
    /**
     * @summary List all comments in a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueGetRepoCommentsResponse>
     */
    issueGetRepoComments(owner: string, repo: string, options?: Models.GiteaAPIIssueGetRepoCommentsOptionalParams): Promise<Models.IssueGetRepoCommentsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    issueGetRepoComments(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Comment[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    issueGetRepoComments(owner: string, repo: string, options: Models.GiteaAPIIssueGetRepoCommentsOptionalParams, callback: msRest.ServiceCallback<Models.Comment[]>): void;
    /**
     * @summary Get a comment
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueGetCommentResponse>
     */
    issueGetComment(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueGetCommentResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment
     * @param callback The callback
     */
    issueGetComment(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Comment>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment
     * @param options The optional parameters
     * @param callback The callback
     */
    issueGetComment(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Comment>): void;
    /**
     * @summary Delete a comment
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of comment to delete
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueDeleteCommentResponse>
     */
    issueDeleteComment(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueDeleteCommentResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of comment to delete
     * @param callback The callback
     */
    issueDeleteComment(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of comment to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    issueDeleteComment(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Edit a comment
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueEditCommentResponse>
     */
    issueEditComment(owner: string, repo: string, id: number, options?: Models.GiteaAPIIssueEditCommentOptionalParams): Promise<Models.IssueEditCommentResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment to edit
     * @param callback The callback
     */
    issueEditComment(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Comment>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    issueEditComment(owner: string, repo: string, id: number, options: Models.GiteaAPIIssueEditCommentOptionalParams, callback: msRest.ServiceCallback<Models.Comment>): void;
    /**
     * @summary Get a list of reactions from a comment of an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueGetCommentReactionsResponse>
     */
    issueGetCommentReactions(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueGetCommentReactionsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment to edit
     * @param callback The callback
     */
    issueGetCommentReactions(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Reaction[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    issueGetCommentReactions(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Reaction[]>): void;
    /**
     * @summary Add a reaction to a comment of an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.IssuePostCommentReactionResponse>
     */
    issuePostCommentReaction(owner: string, repo: string, id: number, options?: Models.GiteaAPIIssuePostCommentReactionOptionalParams): Promise<Models.IssuePostCommentReactionResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment to edit
     * @param callback The callback
     */
    issuePostCommentReaction(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Reaction>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    issuePostCommentReaction(owner: string, repo: string, id: number, options: Models.GiteaAPIIssuePostCommentReactionOptionalParams, callback: msRest.ServiceCallback<Models.Reaction>): void;
    /**
     * @summary Remove a reaction from a comment of an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueDeleteCommentReactionResponse>
     */
    issueDeleteCommentReaction(owner: string, repo: string, id: number, options?: Models.GiteaAPIIssueDeleteCommentReactionOptionalParams): Promise<Models.IssueDeleteCommentReactionResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment to edit
     * @param callback The callback
     */
    issueDeleteCommentReaction(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the comment to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    issueDeleteCommentReaction(owner: string, repo: string, id: number, options: Models.GiteaAPIIssueDeleteCommentReactionOptionalParams, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Get an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to get
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueGetIssueResponse>
     */
    issueGetIssue(owner: string, repo: string, index: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueGetIssueResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to get
     * @param callback The callback
     */
    issueGetIssue(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.Issue>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to get
     * @param options The optional parameters
     * @param callback The callback
     */
    issueGetIssue(owner: string, repo: string, index: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Issue>): void;
    /**
     * @summary Edit an issue. If using deadline only the date will be taken into account, and time of
     * day ignored.
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueEditIssueResponse>
     */
    issueEditIssue(owner: string, repo: string, index: number, options?: Models.GiteaAPIIssueEditIssueOptionalParams): Promise<Models.IssueEditIssueResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to edit
     * @param callback The callback
     */
    issueEditIssue(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.Issue>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    issueEditIssue(owner: string, repo: string, index: number, options: Models.GiteaAPIIssueEditIssueOptionalParams, callback: msRest.ServiceCallback<Models.Issue>): void;
    /**
     * @summary List all comments on an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueGetCommentsResponse>
     */
    issueGetComments(owner: string, repo: string, index: number, options?: Models.GiteaAPIIssueGetCommentsOptionalParams): Promise<Models.IssueGetCommentsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issueGetComments(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.Comment[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issueGetComments(owner: string, repo: string, index: number, options: Models.GiteaAPIIssueGetCommentsOptionalParams, callback: msRest.ServiceCallback<Models.Comment[]>): void;
    /**
     * @summary Add a comment to an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueCreateCommentResponse>
     */
    issueCreateComment(owner: string, repo: string, index: number, options?: Models.GiteaAPIIssueCreateCommentOptionalParams): Promise<Models.IssueCreateCommentResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issueCreateComment(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.Comment>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issueCreateComment(owner: string, repo: string, index: number, options: Models.GiteaAPIIssueCreateCommentOptionalParams, callback: msRest.ServiceCallback<Models.Comment>): void;
    /**
     * @summary Delete a comment
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index this parameter is ignored
     * @param id id of comment to delete
     * @param [options] The optional parameters
     * @deprecated This operation is deprecated. Please do not use it any longer.
     * @returns Promise<Models.IssueDeleteCommentDeprecatedResponse>
     */
    issueDeleteCommentDeprecated(owner: string, repo: string, index: number, id: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueDeleteCommentDeprecatedResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index this parameter is ignored
     * @param id id of comment to delete
     * @param callback The callback
     * @deprecated This operation is deprecated. Please do not use it any longer.
     */
    issueDeleteCommentDeprecated(owner: string, repo: string, index: number, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index this parameter is ignored
     * @param id id of comment to delete
     * @param options The optional parameters
     * @param callback The callback
     * @deprecated This operation is deprecated. Please do not use it any longer.
     */
    issueDeleteCommentDeprecated(owner: string, repo: string, index: number, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Edit a comment
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index this parameter is ignored
     * @param id id of the comment to edit
     * @param [options] The optional parameters
     * @deprecated This operation is deprecated. Please do not use it any longer.
     * @returns Promise<Models.IssueEditCommentDeprecatedResponse>
     */
    issueEditCommentDeprecated(owner: string, repo: string, index: number, id: number, options?: Models.GiteaAPIIssueEditCommentDeprecatedOptionalParams): Promise<Models.IssueEditCommentDeprecatedResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index this parameter is ignored
     * @param id id of the comment to edit
     * @param callback The callback
     * @deprecated This operation is deprecated. Please do not use it any longer.
     */
    issueEditCommentDeprecated(owner: string, repo: string, index: number, id: number, callback: msRest.ServiceCallback<Models.Comment>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index this parameter is ignored
     * @param id id of the comment to edit
     * @param options The optional parameters
     * @param callback The callback
     * @deprecated This operation is deprecated. Please do not use it any longer.
     */
    issueEditCommentDeprecated(owner: string, repo: string, index: number, id: number, options: Models.GiteaAPIIssueEditCommentDeprecatedOptionalParams, callback: msRest.ServiceCallback<Models.Comment>): void;
    /**
     * @summary Set an issue deadline. If set to null, the deadline is deleted. If using deadline only
     * the date will be taken into account, and time of day ignored.
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to create or update a deadline on
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueEditIssueDeadlineResponse>
     */
    issueEditIssueDeadline(owner: string, repo: string, index: number, options?: Models.GiteaAPIIssueEditIssueDeadlineOptionalParams): Promise<Models.IssueEditIssueDeadlineResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to create or update a deadline on
     * @param callback The callback
     */
    issueEditIssueDeadline(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.IssueDeadline>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to create or update a deadline on
     * @param options The optional parameters
     * @param callback The callback
     */
    issueEditIssueDeadline(owner: string, repo: string, index: number, options: Models.GiteaAPIIssueEditIssueDeadlineOptionalParams, callback: msRest.ServiceCallback<Models.IssueDeadline>): void;
    /**
     * @summary Get an issue's labels
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueGetLabelsResponse>
     */
    issueGetLabels(owner: string, repo: string, index: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueGetLabelsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issueGetLabels(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.Label[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issueGetLabels(owner: string, repo: string, index: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Label[]>): void;
    /**
     * @summary Replace an issue's labels
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueReplaceLabelsResponse>
     */
    issueReplaceLabels(owner: string, repo: string, index: number, options?: Models.GiteaAPIIssueReplaceLabelsOptionalParams): Promise<Models.IssueReplaceLabelsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issueReplaceLabels(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.Label[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issueReplaceLabels(owner: string, repo: string, index: number, options: Models.GiteaAPIIssueReplaceLabelsOptionalParams, callback: msRest.ServiceCallback<Models.Label[]>): void;
    /**
     * @summary Add a label to an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueAddLabelResponse>
     */
    issueAddLabel(owner: string, repo: string, index: number, options?: Models.GiteaAPIIssueAddLabelOptionalParams): Promise<Models.IssueAddLabelResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issueAddLabel(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.Label[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issueAddLabel(owner: string, repo: string, index: number, options: Models.GiteaAPIIssueAddLabelOptionalParams, callback: msRest.ServiceCallback<Models.Label[]>): void;
    /**
     * @summary Remove all labels from an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueClearLabelsResponse>
     */
    issueClearLabels(owner: string, repo: string, index: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueClearLabelsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issueClearLabels(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issueClearLabels(owner: string, repo: string, index: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Remove a label from an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param id id of the label to remove
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueRemoveLabelResponse>
     */
    issueRemoveLabel(owner: string, repo: string, index: number, id: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueRemoveLabelResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param id id of the label to remove
     * @param callback The callback
     */
    issueRemoveLabel(owner: string, repo: string, index: number, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param id id of the label to remove
     * @param options The optional parameters
     * @param callback The callback
     */
    issueRemoveLabel(owner: string, repo: string, index: number, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Get a list reactions of an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueGetIssueReactionsResponse>
     */
    issueGetIssueReactions(owner: string, repo: string, index: number, options?: Models.GiteaAPIIssueGetIssueReactionsOptionalParams): Promise<Models.IssueGetIssueReactionsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issueGetIssueReactions(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.Reaction[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issueGetIssueReactions(owner: string, repo: string, index: number, options: Models.GiteaAPIIssueGetIssueReactionsOptionalParams, callback: msRest.ServiceCallback<Models.Reaction[]>): void;
    /**
     * @summary Add a reaction to an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssuePostIssueReactionResponse>
     */
    issuePostIssueReaction(owner: string, repo: string, index: number, options?: Models.GiteaAPIIssuePostIssueReactionOptionalParams): Promise<Models.IssuePostIssueReactionResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issuePostIssueReaction(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.Reaction>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issuePostIssueReaction(owner: string, repo: string, index: number, options: Models.GiteaAPIIssuePostIssueReactionOptionalParams, callback: msRest.ServiceCallback<Models.Reaction>): void;
    /**
     * @summary Remove a reaction from an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueDeleteIssueReactionResponse>
     */
    issueDeleteIssueReaction(owner: string, repo: string, index: number, options?: Models.GiteaAPIIssueDeleteIssueReactionOptionalParams): Promise<Models.IssueDeleteIssueReactionResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issueDeleteIssueReaction(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issueDeleteIssueReaction(owner: string, repo: string, index: number, options: Models.GiteaAPIIssueDeleteIssueReactionOptionalParams, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Delete an issue's existing stopwatch.
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to stop the stopwatch on
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    issueDeleteStopWatch(owner: string, repo: string, index: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to stop the stopwatch on
     * @param callback The callback
     */
    issueDeleteStopWatch(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to stop the stopwatch on
     * @param options The optional parameters
     * @param callback The callback
     */
    issueDeleteStopWatch(owner: string, repo: string, index: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Start stopwatch on an issue.
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to create the stopwatch on
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    issueStartStopWatch(owner: string, repo: string, index: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to create the stopwatch on
     * @param callback The callback
     */
    issueStartStopWatch(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to create the stopwatch on
     * @param options The optional parameters
     * @param callback The callback
     */
    issueStartStopWatch(owner: string, repo: string, index: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Stop an issue's existing stopwatch.
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to stop the stopwatch on
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    issueStopStopWatch(owner: string, repo: string, index: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to stop the stopwatch on
     * @param callback The callback
     */
    issueStopStopWatch(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to stop the stopwatch on
     * @param options The optional parameters
     * @param callback The callback
     */
    issueStopStopWatch(owner: string, repo: string, index: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Get users who subscribed on an issue.
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueSubscriptionsResponse>
     */
    issueSubscriptions(owner: string, repo: string, index: number, options?: Models.GiteaAPIIssueSubscriptionsOptionalParams): Promise<Models.IssueSubscriptionsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issueSubscriptions(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issueSubscriptions(owner: string, repo: string, index: number, options: Models.GiteaAPIIssueSubscriptionsOptionalParams, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @summary Check if user is subscribed to an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueCheckSubscriptionResponse>
     */
    issueCheckSubscription(owner: string, repo: string, index: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueCheckSubscriptionResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issueCheckSubscription(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.WatchInfo>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issueCheckSubscription(owner: string, repo: string, index: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.WatchInfo>): void;
    /**
     * @summary Subscribe user to issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param user user to subscribe
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    issueAddSubscription(owner: string, repo: string, index: number, user: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param user user to subscribe
     * @param callback The callback
     */
    issueAddSubscription(owner: string, repo: string, index: number, user: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param user user to subscribe
     * @param options The optional parameters
     * @param callback The callback
     */
    issueAddSubscription(owner: string, repo: string, index: number, user: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Unsubscribe user from issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param user user witch unsubscribe
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    issueDeleteSubscription(owner: string, repo: string, index: number, user: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param user user witch unsubscribe
     * @param callback The callback
     */
    issueDeleteSubscription(owner: string, repo: string, index: number, user: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param user user witch unsubscribe
     * @param options The optional parameters
     * @param callback The callback
     */
    issueDeleteSubscription(owner: string, repo: string, index: number, user: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List an issue's tracked times
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueTrackedTimesResponse>
     */
    issueTrackedTimes(owner: string, repo: string, index: number, options?: Models.GiteaAPIIssueTrackedTimesOptionalParams): Promise<Models.IssueTrackedTimesResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issueTrackedTimes(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.TrackedTime[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issueTrackedTimes(owner: string, repo: string, index: number, options: Models.GiteaAPIIssueTrackedTimesOptionalParams, callback: msRest.ServiceCallback<Models.TrackedTime[]>): void;
    /**
     * @summary Add tracked time to a issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueAddTimeResponse>
     */
    issueAddTime(owner: string, repo: string, index: number, options?: Models.GiteaAPIIssueAddTimeOptionalParams): Promise<Models.IssueAddTimeResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param callback The callback
     */
    issueAddTime(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.TrackedTime>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param options The optional parameters
     * @param callback The callback
     */
    issueAddTime(owner: string, repo: string, index: number, options: Models.GiteaAPIIssueAddTimeOptionalParams, callback: msRest.ServiceCallback<Models.TrackedTime>): void;
    /**
     * @summary Reset a tracked time of an issue
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to add tracked time to
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueResetTimeResponse>
     */
    issueResetTime(owner: string, repo: string, index: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueResetTimeResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to add tracked time to
     * @param callback The callback
     */
    issueResetTime(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue to add tracked time to
     * @param options The optional parameters
     * @param callback The callback
     */
    issueResetTime(owner: string, repo: string, index: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Delete specific tracked time
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param id id of time to delete
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueDeleteTimeResponse>
     */
    issueDeleteTime(owner: string, repo: string, index: number, id: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueDeleteTimeResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param id id of time to delete
     * @param callback The callback
     */
    issueDeleteTime(owner: string, repo: string, index: number, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the issue
     * @param id id of time to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    issueDeleteTime(owner: string, repo: string, index: number, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List a repository's keys
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListKeysResponse>
     */
    repoListKeys(owner: string, repo: string, options?: Models.GiteaAPIRepoListKeysOptionalParams): Promise<Models.RepoListKeysResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListKeys(owner: string, repo: string, callback: msRest.ServiceCallback<Models.DeployKey[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListKeys(owner: string, repo: string, options: Models.GiteaAPIRepoListKeysOptionalParams, callback: msRest.ServiceCallback<Models.DeployKey[]>): void;
    /**
     * @summary Add a key to a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoCreateKeyResponse>
     */
    repoCreateKey(owner: string, repo: string, options?: Models.GiteaAPIRepoCreateKeyOptionalParams): Promise<Models.RepoCreateKeyResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoCreateKey(owner: string, repo: string, callback: msRest.ServiceCallback<Models.DeployKey>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoCreateKey(owner: string, repo: string, options: Models.GiteaAPIRepoCreateKeyOptionalParams, callback: msRest.ServiceCallback<Models.DeployKey>): void;
    /**
     * @summary Get a repository's key by id
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the key to get
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetKeyResponse>
     */
    repoGetKey(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetKeyResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the key to get
     * @param callback The callback
     */
    repoGetKey(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.DeployKey>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the key to get
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetKey(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DeployKey>): void;
    /**
     * @summary Delete a key from a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the key to delete
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoDeleteKeyResponse>
     */
    repoDeleteKey(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.RepoDeleteKeyResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the key to delete
     * @param callback The callback
     */
    repoDeleteKey(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the key to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    repoDeleteKey(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Get all of a repository's labels
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueListLabelsResponse>
     */
    issueListLabels(owner: string, repo: string, options?: Models.GiteaAPIIssueListLabelsOptionalParams): Promise<Models.IssueListLabelsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    issueListLabels(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Label[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    issueListLabels(owner: string, repo: string, options: Models.GiteaAPIIssueListLabelsOptionalParams, callback: msRest.ServiceCallback<Models.Label[]>): void;
    /**
     * @summary Create a label
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueCreateLabelResponse>
     */
    issueCreateLabel(owner: string, repo: string, options?: Models.GiteaAPIIssueCreateLabelOptionalParams): Promise<Models.IssueCreateLabelResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    issueCreateLabel(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Label>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    issueCreateLabel(owner: string, repo: string, options: Models.GiteaAPIIssueCreateLabelOptionalParams, callback: msRest.ServiceCallback<Models.Label>): void;
    /**
     * @summary Get a single label
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the label to get
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueGetLabelResponse>
     */
    issueGetLabel(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueGetLabelResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the label to get
     * @param callback The callback
     */
    issueGetLabel(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Label>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the label to get
     * @param options The optional parameters
     * @param callback The callback
     */
    issueGetLabel(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Label>): void;
    /**
     * @summary Delete a label
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the label to delete
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    issueDeleteLabel(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the label to delete
     * @param callback The callback
     */
    issueDeleteLabel(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the label to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    issueDeleteLabel(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Update a label
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the label to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueEditLabelResponse>
     */
    issueEditLabel(owner: string, repo: string, id: number, options?: Models.GiteaAPIIssueEditLabelOptionalParams): Promise<Models.IssueEditLabelResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the label to edit
     * @param callback The callback
     */
    issueEditLabel(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Label>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the label to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    issueEditLabel(owner: string, repo: string, id: number, options: Models.GiteaAPIIssueEditLabelOptionalParams, callback: msRest.ServiceCallback<Models.Label>): void;
    /**
     * @summary Get all of a repository's opened milestones
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueGetMilestonesListResponse>
     */
    issueGetMilestonesList(owner: string, repo: string, options?: Models.GiteaAPIIssueGetMilestonesListOptionalParams): Promise<Models.IssueGetMilestonesListResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    issueGetMilestonesList(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Milestone[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    issueGetMilestonesList(owner: string, repo: string, options: Models.GiteaAPIIssueGetMilestonesListOptionalParams, callback: msRest.ServiceCallback<Models.Milestone[]>): void;
    /**
     * @summary Create a milestone
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueCreateMilestoneResponse>
     */
    issueCreateMilestone(owner: string, repo: string, options?: Models.GiteaAPIIssueCreateMilestoneOptionalParams): Promise<Models.IssueCreateMilestoneResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    issueCreateMilestone(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Milestone>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    issueCreateMilestone(owner: string, repo: string, options: Models.GiteaAPIIssueCreateMilestoneOptionalParams, callback: msRest.ServiceCallback<Models.Milestone>): void;
    /**
     * @summary Get a milestone
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the milestone
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueGetMilestoneResponse>
     */
    issueGetMilestone(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.IssueGetMilestoneResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the milestone
     * @param callback The callback
     */
    issueGetMilestone(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Milestone>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the milestone
     * @param options The optional parameters
     * @param callback The callback
     */
    issueGetMilestone(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Milestone>): void;
    /**
     * @summary Delete a milestone
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the milestone to delete
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    issueDeleteMilestone(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the milestone to delete
     * @param callback The callback
     */
    issueDeleteMilestone(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the milestone to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    issueDeleteMilestone(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Update a milestone
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the milestone
     * @param [options] The optional parameters
     * @returns Promise<Models.IssueEditMilestoneResponse>
     */
    issueEditMilestone(owner: string, repo: string, id: number, options?: Models.GiteaAPIIssueEditMilestoneOptionalParams): Promise<Models.IssueEditMilestoneResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the milestone
     * @param callback The callback
     */
    issueEditMilestone(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Milestone>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the milestone
     * @param options The optional parameters
     * @param callback The callback
     */
    issueEditMilestone(owner: string, repo: string, id: number, options: Models.GiteaAPIIssueEditMilestoneOptionalParams, callback: msRest.ServiceCallback<Models.Milestone>): void;
    /**
     * @summary Sync a mirrored repository
     * @param owner owner of the repo to sync
     * @param repo name of the repo to sync
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoMirrorSyncResponse>
     */
    repoMirrorSync(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoMirrorSyncResponse>;
    /**
     * @param owner owner of the repo to sync
     * @param repo name of the repo to sync
     * @param callback The callback
     */
    repoMirrorSync(owner: string, repo: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo to sync
     * @param repo name of the repo to sync
     * @param options The optional parameters
     * @param callback The callback
     */
    repoMirrorSync(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List users's notification threads on a specific repo
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.NotifyGetRepoListResponse>
     */
    notifyGetRepoList(owner: string, repo: string, options?: Models.GiteaAPINotifyGetRepoListOptionalParams): Promise<Models.NotifyGetRepoListResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    notifyGetRepoList(owner: string, repo: string, callback: msRest.ServiceCallback<Models.NotificationThread[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    notifyGetRepoList(owner: string, repo: string, options: Models.GiteaAPINotifyGetRepoListOptionalParams, callback: msRest.ServiceCallback<Models.NotificationThread[]>): void;
    /**
     * @summary Mark notification threads as read on a specific repo
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    notifyReadRepoList(owner: string, repo: string, options?: Models.GiteaAPINotifyReadRepoListOptionalParams): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    notifyReadRepoList(owner: string, repo: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    notifyReadRepoList(owner: string, repo: string, options: Models.GiteaAPINotifyReadRepoListOptionalParams, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List a repo's pull requests
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListPullRequestsResponse>
     */
    repoListPullRequests(owner: string, repo: string, options?: Models.GiteaAPIRepoListPullRequestsOptionalParams): Promise<Models.RepoListPullRequestsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListPullRequests(owner: string, repo: string, callback: msRest.ServiceCallback<Models.PullRequest[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListPullRequests(owner: string, repo: string, options: Models.GiteaAPIRepoListPullRequestsOptionalParams, callback: msRest.ServiceCallback<Models.PullRequest[]>): void;
    /**
     * @summary Create a pull request
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoCreatePullRequestResponse>
     */
    repoCreatePullRequest(owner: string, repo: string, options?: Models.GiteaAPIRepoCreatePullRequestOptionalParams): Promise<Models.RepoCreatePullRequestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoCreatePullRequest(owner: string, repo: string, callback: msRest.ServiceCallback<Models.PullRequest>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoCreatePullRequest(owner: string, repo: string, options: Models.GiteaAPIRepoCreatePullRequestOptionalParams, callback: msRest.ServiceCallback<Models.PullRequest>): void;
    /**
     * @summary Get a pull request
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request to get
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetPullRequestResponse>
     */
    repoGetPullRequest(owner: string, repo: string, index: number, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetPullRequestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request to get
     * @param callback The callback
     */
    repoGetPullRequest(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.PullRequest>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request to get
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetPullRequest(owner: string, repo: string, index: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PullRequest>): void;
    /**
     * @summary Update a pull request. If using deadline only the date will be taken into account, and
     * time of day ignored.
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoEditPullRequestResponse>
     */
    repoEditPullRequest(owner: string, repo: string, index: number, options?: Models.GiteaAPIRepoEditPullRequestOptionalParams): Promise<Models.RepoEditPullRequestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request to edit
     * @param callback The callback
     */
    repoEditPullRequest(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.PullRequest>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    repoEditPullRequest(owner: string, repo: string, index: number, options: Models.GiteaAPIRepoEditPullRequestOptionalParams, callback: msRest.ServiceCallback<Models.PullRequest>): void;
    /**
     * @summary Check if a pull request has been merged
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    repoPullRequestIsMerged(owner: string, repo: string, index: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param callback The callback
     */
    repoPullRequestIsMerged(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param options The optional parameters
     * @param callback The callback
     */
    repoPullRequestIsMerged(owner: string, repo: string, index: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Merge a pull request
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request to merge
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoMergePullRequestResponse>
     */
    repoMergePullRequest(owner: string, repo: string, index: number, options?: Models.GiteaAPIRepoMergePullRequestOptionalParams): Promise<Models.RepoMergePullRequestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request to merge
     * @param callback The callback
     */
    repoMergePullRequest(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request to merge
     * @param options The optional parameters
     * @param callback The callback
     */
    repoMergePullRequest(owner: string, repo: string, index: number, options: Models.GiteaAPIRepoMergePullRequestOptionalParams, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List all reviews for a pull request
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListPullReviewsResponse>
     */
    repoListPullReviews(owner: string, repo: string, index: number, options?: Models.GiteaAPIRepoListPullReviewsOptionalParams): Promise<Models.RepoListPullReviewsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param callback The callback
     */
    repoListPullReviews(owner: string, repo: string, index: number, callback: msRest.ServiceCallback<Models.PullReview[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListPullReviews(owner: string, repo: string, index: number, options: Models.GiteaAPIRepoListPullReviewsOptionalParams, callback: msRest.ServiceCallback<Models.PullReview[]>): void;
    /**
     * @summary Create a review to an pull request
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoCreatePullReviewResponse>
     */
    repoCreatePullReview(owner: string, repo: string, index: number, body: Models.CreatePullReviewOptions, options?: msRest.RequestOptionsBase): Promise<Models.RepoCreatePullReviewResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param body
     * @param callback The callback
     */
    repoCreatePullReview(owner: string, repo: string, index: number, body: Models.CreatePullReviewOptions, callback: msRest.ServiceCallback<Models.PullReview>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param body
     * @param options The optional parameters
     * @param callback The callback
     */
    repoCreatePullReview(owner: string, repo: string, index: number, body: Models.CreatePullReviewOptions, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PullReview>): void;
    /**
     * @summary Get a specific review for a pull request
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param id id of the review
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetPullReviewResponse>
     */
    repoGetPullReview(owner: string, repo: string, index: number, id: number, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetPullReviewResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param id id of the review
     * @param callback The callback
     */
    repoGetPullReview(owner: string, repo: string, index: number, id: number, callback: msRest.ServiceCallback<Models.PullReview>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param id id of the review
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetPullReview(owner: string, repo: string, index: number, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PullReview>): void;
    /**
     * @summary Submit a pending review to an pull request
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param id id of the review
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoSubmitPullReviewResponse>
     */
    repoSubmitPullReview(owner: string, repo: string, index: number, id: number, body: Models.SubmitPullReviewOptions, options?: msRest.RequestOptionsBase): Promise<Models.RepoSubmitPullReviewResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param id id of the review
     * @param body
     * @param callback The callback
     */
    repoSubmitPullReview(owner: string, repo: string, index: number, id: number, body: Models.SubmitPullReviewOptions, callback: msRest.ServiceCallback<Models.PullReview>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param id id of the review
     * @param body
     * @param options The optional parameters
     * @param callback The callback
     */
    repoSubmitPullReview(owner: string, repo: string, index: number, id: number, body: Models.SubmitPullReviewOptions, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PullReview>): void;
    /**
     * @summary Delete a specific review from a pull request
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param id id of the review
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoDeletePullReviewResponse>
     */
    repoDeletePullReview(owner: string, repo: string, index: number, id: number, options?: msRest.RequestOptionsBase): Promise<Models.RepoDeletePullReviewResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param id id of the review
     * @param callback The callback
     */
    repoDeletePullReview(owner: string, repo: string, index: number, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param id id of the review
     * @param options The optional parameters
     * @param callback The callback
     */
    repoDeletePullReview(owner: string, repo: string, index: number, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Get a specific review for a pull request
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param id id of the review
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetPullReviewCommentsResponse>
     */
    repoGetPullReviewComments(owner: string, repo: string, index: number, id: number, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetPullReviewCommentsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param id id of the review
     * @param callback The callback
     */
    repoGetPullReviewComments(owner: string, repo: string, index: number, id: number, callback: msRest.ServiceCallback<Models.PullReviewComment[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param index index of the pull request
     * @param id id of the review
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetPullReviewComments(owner: string, repo: string, index: number, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PullReviewComment[]>): void;
    /**
     * @summary Get a file from a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath filepath of the file to get
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    repoGetRawFile(owner: string, repo: string, filepath: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath filepath of the file to get
     * @param callback The callback
     */
    repoGetRawFile(owner: string, repo: string, filepath: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param filepath filepath of the file to get
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetRawFile(owner: string, repo: string, filepath: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List a repo's releases
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListReleasesResponse>
     */
    repoListReleases(owner: string, repo: string, options?: Models.GiteaAPIRepoListReleasesOptionalParams): Promise<Models.RepoListReleasesResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListReleases(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Release[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListReleases(owner: string, repo: string, options: Models.GiteaAPIRepoListReleasesOptionalParams, callback: msRest.ServiceCallback<Models.Release[]>): void;
    /**
     * @summary Create a release
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoCreateReleaseResponse>
     */
    repoCreateRelease(owner: string, repo: string, options?: Models.GiteaAPIRepoCreateReleaseOptionalParams): Promise<Models.RepoCreateReleaseResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoCreateRelease(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Release>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoCreateRelease(owner: string, repo: string, options: Models.GiteaAPIRepoCreateReleaseOptionalParams, callback: msRest.ServiceCallback<Models.Release>): void;
    /**
     * @summary Get a release
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release to get
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetReleaseResponse>
     */
    repoGetRelease(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetReleaseResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release to get
     * @param callback The callback
     */
    repoGetRelease(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Release>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release to get
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetRelease(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Release>): void;
    /**
     * @summary Delete a release
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release to delete
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    repoDeleteRelease(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release to delete
     * @param callback The callback
     */
    repoDeleteRelease(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    repoDeleteRelease(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Update a release
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoEditReleaseResponse>
     */
    repoEditRelease(owner: string, repo: string, id: number, options?: Models.GiteaAPIRepoEditReleaseOptionalParams): Promise<Models.RepoEditReleaseResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release to edit
     * @param callback The callback
     */
    repoEditRelease(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Release>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    repoEditRelease(owner: string, repo: string, id: number, options: Models.GiteaAPIRepoEditReleaseOptionalParams, callback: msRest.ServiceCallback<Models.Release>): void;
    /**
     * @summary List release's attachments
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListReleaseAttachmentsResponse>
     */
    repoListReleaseAttachments(owner: string, repo: string, id: number, options?: msRest.RequestOptionsBase): Promise<Models.RepoListReleaseAttachmentsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param callback The callback
     */
    repoListReleaseAttachments(owner: string, repo: string, id: number, callback: msRest.ServiceCallback<Models.Attachment[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListReleaseAttachments(owner: string, repo: string, id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Attachment[]>): void;
    /**
     * @summary Create a release attachment
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param attachment attachment to upload
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoCreateReleaseAttachmentResponse>
     */
    repoCreateReleaseAttachment(owner: string, repo: string, id: number, attachment: msRest.HttpRequestBody, options?: Models.GiteaAPIRepoCreateReleaseAttachmentOptionalParams): Promise<Models.RepoCreateReleaseAttachmentResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param attachment attachment to upload
     * @param callback The callback
     */
    repoCreateReleaseAttachment(owner: string, repo: string, id: number, attachment: msRest.HttpRequestBody, callback: msRest.ServiceCallback<Models.Attachment>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param attachment attachment to upload
     * @param options The optional parameters
     * @param callback The callback
     */
    repoCreateReleaseAttachment(owner: string, repo: string, id: number, attachment: msRest.HttpRequestBody, options: Models.GiteaAPIRepoCreateReleaseAttachmentOptionalParams, callback: msRest.ServiceCallback<Models.Attachment>): void;
    /**
     * @summary Get a release attachment
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param attachmentId id of the attachment to get
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetReleaseAttachmentResponse>
     */
    repoGetReleaseAttachment(owner: string, repo: string, id: number, attachmentId: number, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetReleaseAttachmentResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param attachmentId id of the attachment to get
     * @param callback The callback
     */
    repoGetReleaseAttachment(owner: string, repo: string, id: number, attachmentId: number, callback: msRest.ServiceCallback<Models.Attachment>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param attachmentId id of the attachment to get
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetReleaseAttachment(owner: string, repo: string, id: number, attachmentId: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Attachment>): void;
    /**
     * @summary Delete a release attachment
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param attachmentId id of the attachment to delete
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    repoDeleteReleaseAttachment(owner: string, repo: string, id: number, attachmentId: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param attachmentId id of the attachment to delete
     * @param callback The callback
     */
    repoDeleteReleaseAttachment(owner: string, repo: string, id: number, attachmentId: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param attachmentId id of the attachment to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    repoDeleteReleaseAttachment(owner: string, repo: string, id: number, attachmentId: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Edit a release attachment
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param attachmentId id of the attachment to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoEditReleaseAttachmentResponse>
     */
    repoEditReleaseAttachment(owner: string, repo: string, id: number, attachmentId: number, options?: Models.GiteaAPIRepoEditReleaseAttachmentOptionalParams): Promise<Models.RepoEditReleaseAttachmentResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param attachmentId id of the attachment to edit
     * @param callback The callback
     */
    repoEditReleaseAttachment(owner: string, repo: string, id: number, attachmentId: number, callback: msRest.ServiceCallback<Models.Attachment>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param id id of the release
     * @param attachmentId id of the attachment to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    repoEditReleaseAttachment(owner: string, repo: string, id: number, attachmentId: number, options: Models.GiteaAPIRepoEditReleaseAttachmentOptionalParams, callback: msRest.ServiceCallback<Models.Attachment>): void;
    /**
     * @summary Get signing-key.gpg for given repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoSigningKeyResponse>
     */
    repoSigningKey(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoSigningKeyResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoSigningKey(owner: string, repo: string, callback: msRest.ServiceCallback<string>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoSigningKey(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<string>): void;
    /**
     * @summary List a repo's stargazers
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListStargazersResponse>
     */
    repoListStargazers(owner: string, repo: string, options?: Models.GiteaAPIRepoListStargazersOptionalParams): Promise<Models.RepoListStargazersResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListStargazers(owner: string, repo: string, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListStargazers(owner: string, repo: string, options: Models.GiteaAPIRepoListStargazersOptionalParams, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @summary Get a commit's statuses
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the commit
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListStatusesResponse>
     */
    repoListStatuses(owner: string, repo: string, sha: string, options?: Models.GiteaAPIRepoListStatusesOptionalParams): Promise<Models.RepoListStatusesResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the commit
     * @param callback The callback
     */
    repoListStatuses(owner: string, repo: string, sha: string, callback: msRest.ServiceCallback<Models.Status[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the commit
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListStatuses(owner: string, repo: string, sha: string, options: Models.GiteaAPIRepoListStatusesOptionalParams, callback: msRest.ServiceCallback<Models.Status[]>): void;
    /**
     * @summary Create a commit status
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the commit
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoCreateStatusResponse>
     */
    repoCreateStatus(owner: string, repo: string, sha: string, options?: Models.GiteaAPIRepoCreateStatusOptionalParams): Promise<Models.RepoCreateStatusResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the commit
     * @param callback The callback
     */
    repoCreateStatus(owner: string, repo: string, sha: string, callback: msRest.ServiceCallback<Models.Status>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param sha sha of the commit
     * @param options The optional parameters
     * @param callback The callback
     */
    repoCreateStatus(owner: string, repo: string, sha: string, options: Models.GiteaAPIRepoCreateStatusOptionalParams, callback: msRest.ServiceCallback<Models.Status>): void;
    /**
     * @summary List a repo's watchers
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListSubscribersResponse>
     */
    repoListSubscribers(owner: string, repo: string, options?: Models.GiteaAPIRepoListSubscribersOptionalParams): Promise<Models.RepoListSubscribersResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListSubscribers(owner: string, repo: string, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListSubscribers(owner: string, repo: string, options: Models.GiteaAPIRepoListSubscribersOptionalParams, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @summary Check if the current user is watching a repo
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentCheckSubscriptionResponse>
     */
    userCurrentCheckSubscription(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<Models.UserCurrentCheckSubscriptionResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    userCurrentCheckSubscription(owner: string, repo: string, callback: msRest.ServiceCallback<Models.WatchInfo>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentCheckSubscription(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.WatchInfo>): void;
    /**
     * @summary Watch a repo
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentPutSubscriptionResponse>
     */
    userCurrentPutSubscription(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<Models.UserCurrentPutSubscriptionResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    userCurrentPutSubscription(owner: string, repo: string, callback: msRest.ServiceCallback<Models.WatchInfo>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentPutSubscription(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.WatchInfo>): void;
    /**
     * @summary Unwatch a repo
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    userCurrentDeleteSubscription(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    userCurrentDeleteSubscription(owner: string, repo: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentDeleteSubscription(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List a repository's tags
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListTagsResponse>
     */
    repoListTags(owner: string, repo: string, options?: Models.GiteaAPIRepoListTagsOptionalParams): Promise<Models.RepoListTagsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListTags(owner: string, repo: string, callback: msRest.ServiceCallback<Models.Tag[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListTags(owner: string, repo: string, options: Models.GiteaAPIRepoListTagsOptionalParams, callback: msRest.ServiceCallback<Models.Tag[]>): void;
    /**
     * @summary List a repo's tracked times
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoTrackedTimesResponse>
     */
    repoTrackedTimes(owner: string, repo: string, options?: Models.GiteaAPIRepoTrackedTimesOptionalParams): Promise<Models.RepoTrackedTimesResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoTrackedTimes(owner: string, repo: string, callback: msRest.ServiceCallback<Models.TrackedTime[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoTrackedTimes(owner: string, repo: string, options: Models.GiteaAPIRepoTrackedTimesOptionalParams, callback: msRest.ServiceCallback<Models.TrackedTime[]>): void;
    /**
     * @summary List a user's tracked times in a repo
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param user username of user
     * @param [options] The optional parameters
     * @deprecated This operation is deprecated. Please do not use it any longer.
     * @returns Promise<Models.UserTrackedTimesResponse>
     */
    userTrackedTimes(owner: string, repo: string, user: string, options?: msRest.RequestOptionsBase): Promise<Models.UserTrackedTimesResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param user username of user
     * @param callback The callback
     * @deprecated This operation is deprecated. Please do not use it any longer.
     */
    userTrackedTimes(owner: string, repo: string, user: string, callback: msRest.ServiceCallback<Models.TrackedTime[]>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param user username of user
     * @param options The optional parameters
     * @param callback The callback
     * @deprecated This operation is deprecated. Please do not use it any longer.
     */
    userTrackedTimes(owner: string, repo: string, user: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.TrackedTime[]>): void;
    /**
     * @summary Get list of topics that a repository has
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoListTopicsResponse>
     */
    repoListTopics(owner: string, repo: string, options?: Models.GiteaAPIRepoListTopicsOptionalParams): Promise<Models.RepoListTopicsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoListTopics(owner: string, repo: string, callback: msRest.ServiceCallback<Models.TopicName>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoListTopics(owner: string, repo: string, options: Models.GiteaAPIRepoListTopicsOptionalParams, callback: msRest.ServiceCallback<Models.TopicName>): void;
    /**
     * @summary Replace list of topics for a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoUpdateTopicsResponse>
     */
    repoUpdateTopics(owner: string, repo: string, options?: Models.GiteaAPIRepoUpdateTopicsOptionalParams): Promise<Models.RepoUpdateTopicsResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    repoUpdateTopics(owner: string, repo: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    repoUpdateTopics(owner: string, repo: string, options: Models.GiteaAPIRepoUpdateTopicsOptionalParams, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Add a topic to a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param topic name of the topic to add
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoAddTopícResponse>
     */
    repoAddTopíc(owner: string, repo: string, topic: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoAddTopícResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param topic name of the topic to add
     * @param callback The callback
     */
    repoAddTopíc(owner: string, repo: string, topic: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param topic name of the topic to add
     * @param options The optional parameters
     * @param callback The callback
     */
    repoAddTopíc(owner: string, repo: string, topic: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Delete a topic from a repository
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param topic name of the topic to delete
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoDeleteTopicResponse>
     */
    repoDeleteTopic(owner: string, repo: string, topic: string, options?: msRest.RequestOptionsBase): Promise<Models.RepoDeleteTopicResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param topic name of the topic to delete
     * @param callback The callback
     */
    repoDeleteTopic(owner: string, repo: string, topic: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param topic name of the topic to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    repoDeleteTopic(owner: string, repo: string, topic: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Transfer a repo ownership
     * @param owner owner of the repo to transfer
     * @param repo name of the repo to transfer
     * @param body Transfer Options
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoTransferResponse>
     */
    repoTransfer(owner: string, repo: string, body: Models.TransferRepoOption, options?: msRest.RequestOptionsBase): Promise<Models.RepoTransferResponse>;
    /**
     * @param owner owner of the repo to transfer
     * @param repo name of the repo to transfer
     * @param body Transfer Options
     * @param callback The callback
     */
    repoTransfer(owner: string, repo: string, body: Models.TransferRepoOption, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @param owner owner of the repo to transfer
     * @param repo name of the repo to transfer
     * @param body Transfer Options
     * @param options The optional parameters
     * @param callback The callback
     */
    repoTransfer(owner: string, repo: string, body: Models.TransferRepoOption, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @summary Get a repository by id
     * @param id id of the repo to get
     * @param [options] The optional parameters
     * @returns Promise<Models.RepoGetByIDResponse>
     */
    repoGetByID(id: number, options?: msRest.RequestOptionsBase): Promise<Models.RepoGetByIDResponse>;
    /**
     * @param id id of the repo to get
     * @param callback The callback
     */
    repoGetByID(id: number, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @param id id of the repo to get
     * @param options The optional parameters
     * @param callback The callback
     */
    repoGetByID(id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @summary Get default signing-key.gpg
     * @param [options] The optional parameters
     * @returns Promise<Models.GetSigningKeyResponse>
     */
    getSigningKey(options?: msRest.RequestOptionsBase): Promise<Models.GetSigningKeyResponse>;
    /**
     * @param callback The callback
     */
    getSigningKey(callback: msRest.ServiceCallback<string>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    getSigningKey(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<string>): void;
    /**
     * @summary Get a team
     * @param id id of the team to get
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgGetTeamResponse>
     */
    orgGetTeam(id: number, options?: msRest.RequestOptionsBase): Promise<Models.OrgGetTeamResponse>;
    /**
     * @param id id of the team to get
     * @param callback The callback
     */
    orgGetTeam(id: number, callback: msRest.ServiceCallback<Models.Team>): void;
    /**
     * @param id id of the team to get
     * @param options The optional parameters
     * @param callback The callback
     */
    orgGetTeam(id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Team>): void;
    /**
     * @summary Delete a team
     * @param id id of the team to delete
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    orgDeleteTeam(id: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param id id of the team to delete
     * @param callback The callback
     */
    orgDeleteTeam(id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param id id of the team to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    orgDeleteTeam(id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Edit a team
     * @param id id of the team to edit
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgEditTeamResponse>
     */
    orgEditTeam(id: number, options?: Models.GiteaAPIOrgEditTeamOptionalParams): Promise<Models.OrgEditTeamResponse>;
    /**
     * @param id id of the team to edit
     * @param callback The callback
     */
    orgEditTeam(id: number, callback: msRest.ServiceCallback<Models.Team>): void;
    /**
     * @param id id of the team to edit
     * @param options The optional parameters
     * @param callback The callback
     */
    orgEditTeam(id: number, options: Models.GiteaAPIOrgEditTeamOptionalParams, callback: msRest.ServiceCallback<Models.Team>): void;
    /**
     * @summary List a team's members
     * @param id id of the team
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgListTeamMembersResponse>
     */
    orgListTeamMembers(id: number, options?: Models.GiteaAPIOrgListTeamMembersOptionalParams): Promise<Models.OrgListTeamMembersResponse>;
    /**
     * @param id id of the team
     * @param callback The callback
     */
    orgListTeamMembers(id: number, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @param id id of the team
     * @param options The optional parameters
     * @param callback The callback
     */
    orgListTeamMembers(id: number, options: Models.GiteaAPIOrgListTeamMembersOptionalParams, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @summary List a particular member of team
     * @param id id of the team
     * @param username username of the member to list
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgListTeamMemberResponse>
     */
    orgListTeamMember(id: number, username: string, options?: msRest.RequestOptionsBase): Promise<Models.OrgListTeamMemberResponse>;
    /**
     * @param id id of the team
     * @param username username of the member to list
     * @param callback The callback
     */
    orgListTeamMember(id: number, username: string, callback: msRest.ServiceCallback<Models.User>): void;
    /**
     * @param id id of the team
     * @param username username of the member to list
     * @param options The optional parameters
     * @param callback The callback
     */
    orgListTeamMember(id: number, username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.User>): void;
    /**
     * @summary Add a team member
     * @param id id of the team
     * @param username username of the user to add
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    orgAddTeamMember(id: number, username: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param id id of the team
     * @param username username of the user to add
     * @param callback The callback
     */
    orgAddTeamMember(id: number, username: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param id id of the team
     * @param username username of the user to add
     * @param options The optional parameters
     * @param callback The callback
     */
    orgAddTeamMember(id: number, username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Remove a team member
     * @param id id of the team
     * @param username username of the user to remove
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    orgRemoveTeamMember(id: number, username: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param id id of the team
     * @param username username of the user to remove
     * @param callback The callback
     */
    orgRemoveTeamMember(id: number, username: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param id id of the team
     * @param username username of the user to remove
     * @param options The optional parameters
     * @param callback The callback
     */
    orgRemoveTeamMember(id: number, username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List a team's repos
     * @param id id of the team
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgListTeamReposResponse>
     */
    orgListTeamRepos(id: number, options?: Models.GiteaAPIOrgListTeamReposOptionalParams): Promise<Models.OrgListTeamReposResponse>;
    /**
     * @param id id of the team
     * @param callback The callback
     */
    orgListTeamRepos(id: number, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @param id id of the team
     * @param options The optional parameters
     * @param callback The callback
     */
    orgListTeamRepos(id: number, options: Models.GiteaAPIOrgListTeamReposOptionalParams, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @summary Add a repository to a team
     * @param id id of the team
     * @param org organization that owns the repo to add
     * @param repo name of the repo to add
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgAddTeamRepositoryResponse>
     */
    orgAddTeamRepository(id: number, org: string, repo: string, options?: msRest.RequestOptionsBase): Promise<Models.OrgAddTeamRepositoryResponse>;
    /**
     * @param id id of the team
     * @param org organization that owns the repo to add
     * @param repo name of the repo to add
     * @param callback The callback
     */
    orgAddTeamRepository(id: number, org: string, repo: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param id id of the team
     * @param org organization that owns the repo to add
     * @param repo name of the repo to add
     * @param options The optional parameters
     * @param callback The callback
     */
    orgAddTeamRepository(id: number, org: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * This does not delete the repository, it only removes the repository from the team.
     * @summary Remove a repository from a team
     * @param id id of the team
     * @param org organization that owns the repo to remove
     * @param repo name of the repo to remove
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgRemoveTeamRepositoryResponse>
     */
    orgRemoveTeamRepository(id: number, org: string, repo: string, options?: msRest.RequestOptionsBase): Promise<Models.OrgRemoveTeamRepositoryResponse>;
    /**
     * @param id id of the team
     * @param org organization that owns the repo to remove
     * @param repo name of the repo to remove
     * @param callback The callback
     */
    orgRemoveTeamRepository(id: number, org: string, repo: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param id id of the team
     * @param org organization that owns the repo to remove
     * @param repo name of the repo to remove
     * @param options The optional parameters
     * @param callback The callback
     */
    orgRemoveTeamRepository(id: number, org: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary search topics via keyword
     * @param q keywords to search
     * @param [options] The optional parameters
     * @returns Promise<Models.TopicSearchResponse>
     */
    topicSearch(q: string, options?: Models.GiteaAPITopicSearchOptionalParams): Promise<Models.TopicSearchResponse>;
    /**
     * @param q keywords to search
     * @param callback The callback
     */
    topicSearch(q: string, callback: msRest.ServiceCallback<Models.TopicResponse[]>): void;
    /**
     * @param q keywords to search
     * @param options The optional parameters
     * @param callback The callback
     */
    topicSearch(q: string, options: Models.GiteaAPITopicSearchOptionalParams, callback: msRest.ServiceCallback<Models.TopicResponse[]>): void;
    /**
     * @summary Get the authenticated user
     * @param [options] The optional parameters
     * @returns Promise<Models.UserGetCurrentResponse>
     */
    userGetCurrent(options?: msRest.RequestOptionsBase): Promise<Models.UserGetCurrentResponse>;
    /**
     * @param callback The callback
     */
    userGetCurrent(callback: msRest.ServiceCallback<Models.User>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userGetCurrent(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.User>): void;
    /**
     * @summary List the authenticated user's oauth2 applications
     * @param [options] The optional parameters
     * @returns Promise<Models.UserGetOauth2ApplicationResponse>
     */
    userGetOauth2Application(options?: Models.GiteaAPIUserGetOauth2ApplicationOptionalParams): Promise<Models.UserGetOauth2ApplicationResponse>;
    /**
     * @param callback The callback
     */
    userGetOauth2Application(callback: msRest.ServiceCallback<Models.OAuth2Application[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userGetOauth2Application(options: Models.GiteaAPIUserGetOauth2ApplicationOptionalParams, callback: msRest.ServiceCallback<Models.OAuth2Application[]>): void;
    /**
     * @summary creates a new OAuth2 application
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCreateOAuth2ApplicationResponse>
     */
    userCreateOAuth2Application(body: Models.CreateOAuth2ApplicationOptions, options?: msRest.RequestOptionsBase): Promise<Models.UserCreateOAuth2ApplicationResponse>;
    /**
     * @param body
     * @param callback The callback
     */
    userCreateOAuth2Application(body: Models.CreateOAuth2ApplicationOptions, callback: msRest.ServiceCallback<Models.OAuth2Application>): void;
    /**
     * @param body
     * @param options The optional parameters
     * @param callback The callback
     */
    userCreateOAuth2Application(body: Models.CreateOAuth2ApplicationOptions, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.OAuth2Application>): void;
    /**
     * @summary get an OAuth2 Application
     * @param id Application ID to be found
     * @param [options] The optional parameters
     * @returns Promise<Models.UserGetOAuth2ApplicationResponse>
     */
    userGetOAuth2Application(id: number, options?: msRest.RequestOptionsBase): Promise<Models.UserGetOAuth2ApplicationResponse>;
    /**
     * @param id Application ID to be found
     * @param callback The callback
     */
    userGetOAuth2Application(id: number, callback: msRest.ServiceCallback<Models.OAuth2Application>): void;
    /**
     * @param id Application ID to be found
     * @param options The optional parameters
     * @param callback The callback
     */
    userGetOAuth2Application(id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.OAuth2Application>): void;
    /**
     * @summary delete an OAuth2 Application
     * @param id token to be deleted
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    userDeleteOAuth2Application(id: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param id token to be deleted
     * @param callback The callback
     */
    userDeleteOAuth2Application(id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param id token to be deleted
     * @param options The optional parameters
     * @param callback The callback
     */
    userDeleteOAuth2Application(id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary update an OAuth2 Application, this includes regenerating the client secret
     * @param id application to be updated
     * @param body
     * @param [options] The optional parameters
     * @returns Promise<Models.UserUpdateOAuth2ApplicationResponse>
     */
    userUpdateOAuth2Application(id: number, body: Models.CreateOAuth2ApplicationOptions, options?: msRest.RequestOptionsBase): Promise<Models.UserUpdateOAuth2ApplicationResponse>;
    /**
     * @param id application to be updated
     * @param body
     * @param callback The callback
     */
    userUpdateOAuth2Application(id: number, body: Models.CreateOAuth2ApplicationOptions, callback: msRest.ServiceCallback<Models.OAuth2Application>): void;
    /**
     * @param id application to be updated
     * @param body
     * @param options The optional parameters
     * @param callback The callback
     */
    userUpdateOAuth2Application(id: number, body: Models.CreateOAuth2ApplicationOptions, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.OAuth2Application>): void;
    /**
     * @summary List the authenticated user's email addresses
     * @param [options] The optional parameters
     * @returns Promise<Models.UserListEmailsResponse>
     */
    userListEmails(options?: msRest.RequestOptionsBase): Promise<Models.UserListEmailsResponse>;
    /**
     * @param callback The callback
     */
    userListEmails(callback: msRest.ServiceCallback<Models.Email[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userListEmails(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.Email[]>): void;
    /**
     * @summary Add email addresses
     * @param [options] The optional parameters
     * @returns Promise<Models.UserAddEmailResponse>
     */
    userAddEmail(options?: Models.GiteaAPIUserAddEmailOptionalParams): Promise<Models.UserAddEmailResponse>;
    /**
     * @param callback The callback
     */
    userAddEmail(callback: msRest.ServiceCallback<Models.Email[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userAddEmail(options: Models.GiteaAPIUserAddEmailOptionalParams, callback: msRest.ServiceCallback<Models.Email[]>): void;
    /**
     * @summary Delete email addresses
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    userDeleteEmail(options?: Models.GiteaAPIUserDeleteEmailOptionalParams): Promise<msRest.RestResponse>;
    /**
     * @param callback The callback
     */
    userDeleteEmail(callback: msRest.ServiceCallback<void>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userDeleteEmail(options: Models.GiteaAPIUserDeleteEmailOptionalParams, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List the authenticated user's followers
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentListFollowersResponse>
     */
    userCurrentListFollowers(options?: Models.GiteaAPIUserCurrentListFollowersOptionalParams): Promise<Models.UserCurrentListFollowersResponse>;
    /**
     * @param callback The callback
     */
    userCurrentListFollowers(callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentListFollowers(options: Models.GiteaAPIUserCurrentListFollowersOptionalParams, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @summary List the users that the authenticated user is following
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentListFollowingResponse>
     */
    userCurrentListFollowing(options?: Models.GiteaAPIUserCurrentListFollowingOptionalParams): Promise<Models.UserCurrentListFollowingResponse>;
    /**
     * @param callback The callback
     */
    userCurrentListFollowing(callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentListFollowing(options: Models.GiteaAPIUserCurrentListFollowingOptionalParams, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @summary Check whether a user is followed by the authenticated user
     * @param username username of followed user
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    userCurrentCheckFollowing(username: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param username username of followed user
     * @param callback The callback
     */
    userCurrentCheckFollowing(username: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param username username of followed user
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentCheckFollowing(username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Follow a user
     * @param username username of user to follow
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    userCurrentPutFollow(username: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param username username of user to follow
     * @param callback The callback
     */
    userCurrentPutFollow(username: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param username username of user to follow
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentPutFollow(username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Unfollow a user
     * @param username username of user to unfollow
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    userCurrentDeleteFollow(username: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param username username of user to unfollow
     * @param callback The callback
     */
    userCurrentDeleteFollow(username: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param username username of user to unfollow
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentDeleteFollow(username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List the authenticated user's GPG keys
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentListGPGKeysResponse>
     */
    userCurrentListGPGKeys(options?: Models.GiteaAPIUserCurrentListGPGKeysOptionalParams): Promise<Models.UserCurrentListGPGKeysResponse>;
    /**
     * @param callback The callback
     */
    userCurrentListGPGKeys(callback: msRest.ServiceCallback<Models.GPGKey[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentListGPGKeys(options: Models.GiteaAPIUserCurrentListGPGKeysOptionalParams, callback: msRest.ServiceCallback<Models.GPGKey[]>): void;
    /**
     * @summary Create a GPG key
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentPostGPGKeyResponse>
     */
    userCurrentPostGPGKey(options?: Models.GiteaAPIUserCurrentPostGPGKeyOptionalParams): Promise<Models.UserCurrentPostGPGKeyResponse>;
    /**
     * @param callback The callback
     */
    userCurrentPostGPGKey(callback: msRest.ServiceCallback<Models.GPGKey>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentPostGPGKey(options: Models.GiteaAPIUserCurrentPostGPGKeyOptionalParams, callback: msRest.ServiceCallback<Models.GPGKey>): void;
    /**
     * @summary Get a GPG key
     * @param id id of key to get
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentGetGPGKeyResponse>
     */
    userCurrentGetGPGKey(id: number, options?: msRest.RequestOptionsBase): Promise<Models.UserCurrentGetGPGKeyResponse>;
    /**
     * @param id id of key to get
     * @param callback The callback
     */
    userCurrentGetGPGKey(id: number, callback: msRest.ServiceCallback<Models.GPGKey>): void;
    /**
     * @param id id of key to get
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentGetGPGKey(id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.GPGKey>): void;
    /**
     * @summary Remove a GPG key
     * @param id id of key to delete
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentDeleteGPGKeyResponse>
     */
    userCurrentDeleteGPGKey(id: number, options?: msRest.RequestOptionsBase): Promise<Models.UserCurrentDeleteGPGKeyResponse>;
    /**
     * @param id id of key to delete
     * @param callback The callback
     */
    userCurrentDeleteGPGKey(id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param id id of key to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentDeleteGPGKey(id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List the authenticated user's public keys
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentListKeysResponse>
     */
    userCurrentListKeys(options?: Models.GiteaAPIUserCurrentListKeysOptionalParams): Promise<Models.UserCurrentListKeysResponse>;
    /**
     * @param callback The callback
     */
    userCurrentListKeys(callback: msRest.ServiceCallback<Models.PublicKey[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentListKeys(options: Models.GiteaAPIUserCurrentListKeysOptionalParams, callback: msRest.ServiceCallback<Models.PublicKey[]>): void;
    /**
     * @summary Create a public key
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentPostKeyResponse>
     */
    userCurrentPostKey(options?: Models.GiteaAPIUserCurrentPostKeyOptionalParams): Promise<Models.UserCurrentPostKeyResponse>;
    /**
     * @param callback The callback
     */
    userCurrentPostKey(callback: msRest.ServiceCallback<Models.PublicKey>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentPostKey(options: Models.GiteaAPIUserCurrentPostKeyOptionalParams, callback: msRest.ServiceCallback<Models.PublicKey>): void;
    /**
     * @summary Get a public key
     * @param id id of key to get
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentGetKeyResponse>
     */
    userCurrentGetKey(id: number, options?: msRest.RequestOptionsBase): Promise<Models.UserCurrentGetKeyResponse>;
    /**
     * @param id id of key to get
     * @param callback The callback
     */
    userCurrentGetKey(id: number, callback: msRest.ServiceCallback<Models.PublicKey>): void;
    /**
     * @param id id of key to get
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentGetKey(id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.PublicKey>): void;
    /**
     * @summary Delete a public key
     * @param id id of key to delete
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentDeleteKeyResponse>
     */
    userCurrentDeleteKey(id: number, options?: msRest.RequestOptionsBase): Promise<Models.UserCurrentDeleteKeyResponse>;
    /**
     * @param id id of key to delete
     * @param callback The callback
     */
    userCurrentDeleteKey(id: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param id id of key to delete
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentDeleteKey(id: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary List the current user's organizations
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgListCurrentUserOrgsResponse>
     */
    orgListCurrentUserOrgs(options?: Models.GiteaAPIOrgListCurrentUserOrgsOptionalParams): Promise<Models.OrgListCurrentUserOrgsResponse>;
    /**
     * @param callback The callback
     */
    orgListCurrentUserOrgs(callback: msRest.ServiceCallback<Models.Organization[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    orgListCurrentUserOrgs(options: Models.GiteaAPIOrgListCurrentUserOrgsOptionalParams, callback: msRest.ServiceCallback<Models.Organization[]>): void;
    /**
     * @summary List the repos that the authenticated user owns or has access to
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentListReposResponse>
     */
    userCurrentListRepos(options?: Models.GiteaAPIUserCurrentListReposOptionalParams): Promise<Models.UserCurrentListReposResponse>;
    /**
     * @param callback The callback
     */
    userCurrentListRepos(callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentListRepos(options: Models.GiteaAPIUserCurrentListReposOptionalParams, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @summary Create a repository
     * @param [options] The optional parameters
     * @returns Promise<Models.CreateCurrentUserRepoResponse>
     */
    createCurrentUserRepo(options?: Models.GiteaAPICreateCurrentUserRepoOptionalParams): Promise<Models.CreateCurrentUserRepoResponse>;
    /**
     * @param callback The callback
     */
    createCurrentUserRepo(callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    createCurrentUserRepo(options: Models.GiteaAPICreateCurrentUserRepoOptionalParams, callback: msRest.ServiceCallback<Models.Repository>): void;
    /**
     * @summary The repos that the authenticated user has starred
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentListStarredResponse>
     */
    userCurrentListStarred(options?: Models.GiteaAPIUserCurrentListStarredOptionalParams): Promise<Models.UserCurrentListStarredResponse>;
    /**
     * @param callback The callback
     */
    userCurrentListStarred(callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentListStarred(options: Models.GiteaAPIUserCurrentListStarredOptionalParams, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @summary Whether the authenticated is starring the repo
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    userCurrentCheckStarring(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param callback The callback
     */
    userCurrentCheckStarring(owner: string, repo: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo
     * @param repo name of the repo
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentCheckStarring(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Star the given repo
     * @param owner owner of the repo to star
     * @param repo name of the repo to star
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    userCurrentPutStar(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo to star
     * @param repo name of the repo to star
     * @param callback The callback
     */
    userCurrentPutStar(owner: string, repo: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo to star
     * @param repo name of the repo to star
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentPutStar(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Unstar the given repo
     * @param owner owner of the repo to unstar
     * @param repo name of the repo to unstar
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    userCurrentDeleteStar(owner: string, repo: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param owner owner of the repo to unstar
     * @param repo name of the repo to unstar
     * @param callback The callback
     */
    userCurrentDeleteStar(owner: string, repo: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param owner owner of the repo to unstar
     * @param repo name of the repo to unstar
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentDeleteStar(owner: string, repo: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Get list of all existing stopwatches
     * @param [options] The optional parameters
     * @returns Promise<Models.UserGetStopWatchesResponse>
     */
    userGetStopWatches(options?: Models.GiteaAPIUserGetStopWatchesOptionalParams): Promise<Models.UserGetStopWatchesResponse>;
    /**
     * @param callback The callback
     */
    userGetStopWatches(callback: msRest.ServiceCallback<Models.StopWatch[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userGetStopWatches(options: Models.GiteaAPIUserGetStopWatchesOptionalParams, callback: msRest.ServiceCallback<Models.StopWatch[]>): void;
    /**
     * @summary List repositories watched by the authenticated user
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentListSubscriptionsResponse>
     */
    userCurrentListSubscriptions(options?: Models.GiteaAPIUserCurrentListSubscriptionsOptionalParams): Promise<Models.UserCurrentListSubscriptionsResponse>;
    /**
     * @param callback The callback
     */
    userCurrentListSubscriptions(callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentListSubscriptions(options: Models.GiteaAPIUserCurrentListSubscriptionsOptionalParams, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @summary List all the teams a user belongs to
     * @param [options] The optional parameters
     * @returns Promise<Models.UserListTeamsResponse>
     */
    userListTeams(options?: Models.GiteaAPIUserListTeamsOptionalParams): Promise<Models.UserListTeamsResponse>;
    /**
     * @param callback The callback
     */
    userListTeams(callback: msRest.ServiceCallback<Models.Team[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userListTeams(options: Models.GiteaAPIUserListTeamsOptionalParams, callback: msRest.ServiceCallback<Models.Team[]>): void;
    /**
     * @summary List the current user's tracked times
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCurrentTrackedTimesResponse>
     */
    userCurrentTrackedTimes(options?: Models.GiteaAPIUserCurrentTrackedTimesOptionalParams): Promise<Models.UserCurrentTrackedTimesResponse>;
    /**
     * @param callback The callback
     */
    userCurrentTrackedTimes(callback: msRest.ServiceCallback<Models.TrackedTime[]>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userCurrentTrackedTimes(options: Models.GiteaAPIUserCurrentTrackedTimesOptionalParams, callback: msRest.ServiceCallback<Models.TrackedTime[]>): void;
    /**
     * @summary Search for users
     * @param [options] The optional parameters
     * @returns Promise<Models.UserSearchResponse>
     */
    userSearch(options?: Models.GiteaAPIUserSearchOptionalParams): Promise<Models.UserSearchResponse>;
    /**
     * @param callback The callback
     */
    userSearch(callback: msRest.ServiceCallback<Models.UserSearchOKResponse>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    userSearch(options: Models.GiteaAPIUserSearchOptionalParams, callback: msRest.ServiceCallback<Models.UserSearchOKResponse>): void;
    /**
     * @summary Check if one user is following another user
     * @param follower username of following user
     * @param followee username of followed user
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    userCheckFollowing(follower: string, followee: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param follower username of following user
     * @param followee username of followed user
     * @param callback The callback
     */
    userCheckFollowing(follower: string, followee: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param follower username of following user
     * @param followee username of followed user
     * @param options The optional parameters
     * @param callback The callback
     */
    userCheckFollowing(follower: string, followee: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Get a user
     * @param username username of user to get
     * @param [options] The optional parameters
     * @returns Promise<Models.UserGetResponse>
     */
    userGet(username: string, options?: msRest.RequestOptionsBase): Promise<Models.UserGetResponse>;
    /**
     * @param username username of user to get
     * @param callback The callback
     */
    userGet(username: string, callback: msRest.ServiceCallback<Models.User>): void;
    /**
     * @param username username of user to get
     * @param options The optional parameters
     * @param callback The callback
     */
    userGet(username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.User>): void;
    /**
     * @summary List the given user's followers
     * @param username username of user
     * @param [options] The optional parameters
     * @returns Promise<Models.UserListFollowersResponse>
     */
    userListFollowers(username: string, options?: Models.GiteaAPIUserListFollowersOptionalParams): Promise<Models.UserListFollowersResponse>;
    /**
     * @param username username of user
     * @param callback The callback
     */
    userListFollowers(username: string, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @param username username of user
     * @param options The optional parameters
     * @param callback The callback
     */
    userListFollowers(username: string, options: Models.GiteaAPIUserListFollowersOptionalParams, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @summary List the users that the given user is following
     * @param username username of user
     * @param [options] The optional parameters
     * @returns Promise<Models.UserListFollowingResponse>
     */
    userListFollowing(username: string, options?: Models.GiteaAPIUserListFollowingOptionalParams): Promise<Models.UserListFollowingResponse>;
    /**
     * @param username username of user
     * @param callback The callback
     */
    userListFollowing(username: string, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @param username username of user
     * @param options The optional parameters
     * @param callback The callback
     */
    userListFollowing(username: string, options: Models.GiteaAPIUserListFollowingOptionalParams, callback: msRest.ServiceCallback<Models.User[]>): void;
    /**
     * @summary List the given user's GPG keys
     * @param username username of user
     * @param [options] The optional parameters
     * @returns Promise<Models.UserListGPGKeysResponse>
     */
    userListGPGKeys(username: string, options?: Models.GiteaAPIUserListGPGKeysOptionalParams): Promise<Models.UserListGPGKeysResponse>;
    /**
     * @param username username of user
     * @param callback The callback
     */
    userListGPGKeys(username: string, callback: msRest.ServiceCallback<Models.GPGKey[]>): void;
    /**
     * @param username username of user
     * @param options The optional parameters
     * @param callback The callback
     */
    userListGPGKeys(username: string, options: Models.GiteaAPIUserListGPGKeysOptionalParams, callback: msRest.ServiceCallback<Models.GPGKey[]>): void;
    /**
     * @summary Get a user's heatmap
     * @param username username of user to get
     * @param [options] The optional parameters
     * @returns Promise<Models.UserGetHeatmapDataResponse>
     */
    userGetHeatmapData(username: string, options?: msRest.RequestOptionsBase): Promise<Models.UserGetHeatmapDataResponse>;
    /**
     * @param username username of user to get
     * @param callback The callback
     */
    userGetHeatmapData(username: string, callback: msRest.ServiceCallback<Models.UserHeatmapData[]>): void;
    /**
     * @param username username of user to get
     * @param options The optional parameters
     * @param callback The callback
     */
    userGetHeatmapData(username: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.UserHeatmapData[]>): void;
    /**
     * @summary List the given user's public keys
     * @param username username of user
     * @param [options] The optional parameters
     * @returns Promise<Models.UserListKeysResponse>
     */
    userListKeys(username: string, options?: Models.GiteaAPIUserListKeysOptionalParams): Promise<Models.UserListKeysResponse>;
    /**
     * @param username username of user
     * @param callback The callback
     */
    userListKeys(username: string, callback: msRest.ServiceCallback<Models.PublicKey[]>): void;
    /**
     * @param username username of user
     * @param options The optional parameters
     * @param callback The callback
     */
    userListKeys(username: string, options: Models.GiteaAPIUserListKeysOptionalParams, callback: msRest.ServiceCallback<Models.PublicKey[]>): void;
    /**
     * @summary List a user's organizations
     * @param username username of user
     * @param [options] The optional parameters
     * @returns Promise<Models.OrgListUserOrgsResponse>
     */
    orgListUserOrgs(username: string, options?: Models.GiteaAPIOrgListUserOrgsOptionalParams): Promise<Models.OrgListUserOrgsResponse>;
    /**
     * @param username username of user
     * @param callback The callback
     */
    orgListUserOrgs(username: string, callback: msRest.ServiceCallback<Models.Organization[]>): void;
    /**
     * @param username username of user
     * @param options The optional parameters
     * @param callback The callback
     */
    orgListUserOrgs(username: string, options: Models.GiteaAPIOrgListUserOrgsOptionalParams, callback: msRest.ServiceCallback<Models.Organization[]>): void;
    /**
     * @summary List the repos owned by the given user
     * @param username username of user
     * @param [options] The optional parameters
     * @returns Promise<Models.UserListReposResponse>
     */
    userListRepos(username: string, options?: Models.GiteaAPIUserListReposOptionalParams): Promise<Models.UserListReposResponse>;
    /**
     * @param username username of user
     * @param callback The callback
     */
    userListRepos(username: string, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @param username username of user
     * @param options The optional parameters
     * @param callback The callback
     */
    userListRepos(username: string, options: Models.GiteaAPIUserListReposOptionalParams, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @summary The repos that the given user has starred
     * @param username username of user
     * @param [options] The optional parameters
     * @returns Promise<Models.UserListStarredResponse>
     */
    userListStarred(username: string, options?: Models.GiteaAPIUserListStarredOptionalParams): Promise<Models.UserListStarredResponse>;
    /**
     * @param username username of user
     * @param callback The callback
     */
    userListStarred(username: string, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @param username username of user
     * @param options The optional parameters
     * @param callback The callback
     */
    userListStarred(username: string, options: Models.GiteaAPIUserListStarredOptionalParams, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @summary List the repositories watched by a user
     * @param username username of the user
     * @param [options] The optional parameters
     * @returns Promise<Models.UserListSubscriptionsResponse>
     */
    userListSubscriptions(username: string, options?: Models.GiteaAPIUserListSubscriptionsOptionalParams): Promise<Models.UserListSubscriptionsResponse>;
    /**
     * @param username username of the user
     * @param callback The callback
     */
    userListSubscriptions(username: string, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @param username username of the user
     * @param options The optional parameters
     * @param callback The callback
     */
    userListSubscriptions(username: string, options: Models.GiteaAPIUserListSubscriptionsOptionalParams, callback: msRest.ServiceCallback<Models.Repository[]>): void;
    /**
     * @summary List the authenticated user's access tokens
     * @param username username of user
     * @param [options] The optional parameters
     * @returns Promise<Models.UserGetTokensResponse>
     */
    userGetTokens(username: string, options?: Models.GiteaAPIUserGetTokensOptionalParams): Promise<Models.UserGetTokensResponse>;
    /**
     * @param username username of user
     * @param callback The callback
     */
    userGetTokens(username: string, callback: msRest.ServiceCallback<Models.AccessToken[]>): void;
    /**
     * @param username username of user
     * @param options The optional parameters
     * @param callback The callback
     */
    userGetTokens(username: string, options: Models.GiteaAPIUserGetTokensOptionalParams, callback: msRest.ServiceCallback<Models.AccessToken[]>): void;
    /**
     * @summary Create an access token
     * @param username username of user
     * @param [options] The optional parameters
     * @returns Promise<Models.UserCreateTokenResponse>
     */
    userCreateToken(username: string, options?: Models.GiteaAPIUserCreateTokenOptionalParams): Promise<Models.UserCreateTokenResponse>;
    /**
     * @param username username of user
     * @param callback The callback
     */
    userCreateToken(username: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param username username of user
     * @param options The optional parameters
     * @param callback The callback
     */
    userCreateToken(username: string, options: Models.GiteaAPIUserCreateTokenOptionalParams, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary delete an access token
     * @param username username of user
     * @param token token to be deleted
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    userDeleteAccessToken(username: string, token: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param username username of user
     * @param token token to be deleted
     * @param callback The callback
     */
    userDeleteAccessToken(username: string, token: number, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param username username of user
     * @param token token to be deleted
     * @param options The optional parameters
     * @param callback The callback
     */
    userDeleteAccessToken(username: string, token: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
    /**
     * @summary Returns the version of the Gitea application
     * @param [options] The optional parameters
     * @returns Promise<Models.GetVersionResponse>
     */
    getVersion(options?: msRest.RequestOptionsBase): Promise<Models.GetVersionResponse>;
    /**
     * @param callback The callback
     */
    getVersion(callback: msRest.ServiceCallback<Models.ServerVersion>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    getVersion(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ServerVersion>): void;
}
export { GiteaAPI, GiteaAPIContext, Models as GiteaAPIModels, Mappers as GiteaAPIMappers };
//# sourceMappingURL=giteaAPI.d.ts.map